#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_gpu import enable_gpu as enable_gpu_cls
from .term_criterion import term_criterion as term_criterion_cls
from .solver_1 import solver as solver_cls
from .max_num_cycle import max_num_cycle as max_num_cycle_cls
from .coarsen_by_size import coarsen_by_size as coarsen_by_size_cls
from .pre_sweep import pre_sweep as pre_sweep_cls
from .post_sweep import post_sweep as post_sweep_cls
from .smoother import smoother as smoother_cls
class amg_gpgpu_options_child(Group):
    """
    'child_object_type' of amg_gpgpu_options.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['enable_gpu', 'term_criterion', 'solver', 'max_num_cycle',
         'coarsen_by_size', 'pre_sweep', 'post_sweep', 'smoother']

    enable_gpu: enable_gpu_cls = enable_gpu_cls
    """
    enable_gpu child of amg_gpgpu_options_child.
    """
    term_criterion: term_criterion_cls = term_criterion_cls
    """
    term_criterion child of amg_gpgpu_options_child.
    """
    solver: solver_cls = solver_cls
    """
    solver child of amg_gpgpu_options_child.
    """
    max_num_cycle: max_num_cycle_cls = max_num_cycle_cls
    """
    max_num_cycle child of amg_gpgpu_options_child.
    """
    coarsen_by_size: coarsen_by_size_cls = coarsen_by_size_cls
    """
    coarsen_by_size child of amg_gpgpu_options_child.
    """
    pre_sweep: pre_sweep_cls = pre_sweep_cls
    """
    pre_sweep child of amg_gpgpu_options_child.
    """
    post_sweep: post_sweep_cls = post_sweep_cls
    """
    post_sweep child of amg_gpgpu_options_child.
    """
    smoother: smoother_cls = smoother_cls
    """
    smoother child of amg_gpgpu_options_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .single_precision_coordinates import single_precision_coordinates as single_precision_coordinates_cls
from .binary_legacy_files import binary_legacy_files as binary_legacy_files_cls
from .cff_files import cff_files as cff_files_cls
from .convert_hanging_nodes_during_read import convert_hanging_nodes_during_read as convert_hanging_nodes_during_read_cls
from .async_optimize import async_optimize as async_optimize_cls
from .write_pdat import write_pdat as write_pdat_cls
from .confirm_overwrite import confirm_overwrite as confirm_overwrite_cls
from .auto_save import auto_save as auto_save_cls
from .export import export as export_cls
from .import_ import import_ as import__cls
from .parametric_project import parametric_project as parametric_project_cls
from .cffio_options import cffio_options as cffio_options_cls
from .define_macro import define_macro as define_macro_cls
from .execute_macro import execute_macro as execute_macro_cls
from .read_macros import read_macros as read_macros_cls
from .read_1 import read as read_cls
from .read_case import read_case as read_case_cls
from .read_case_data import read_case_data as read_case_data_cls
from .read_case_setting import read_case_setting as read_case_setting_cls
from .read_data import read_data as read_data_cls
from .read_mesh import read_mesh as read_mesh_cls
from .read_journal import read_journal as read_journal_cls
from .start_journal import start_journal as start_journal_cls
from .stop_journal import stop_journal as stop_journal_cls
from .replace_mesh import replace_mesh as replace_mesh_cls
from .write import write as write_cls
from .read_settings import read_settings as read_settings_cls
from .read_field_functions import read_field_functions as read_field_functions_cls
from .read_injections import read_injections as read_injections_cls
from .read_profile import read_profile as read_profile_cls
from .read_pdf import read_pdf as read_pdf_cls
from .read_isat_table import read_isat_table as read_isat_table_cls
from .show_configuration import show_configuration as show_configuration_cls
from .stop_macro import stop_macro as stop_macro_cls
from .start_transcript import start_transcript as start_transcript_cls
from .stop_transcript import stop_transcript as stop_transcript_cls
from .data_file_options import data_file_options as data_file_options_cls
class file(Group):
    """
    'file' child.
    """

    fluent_name = "file"

    child_names = \
        ['single_precision_coordinates', 'binary_legacy_files', 'cff_files',
         'convert_hanging_nodes_during_read', 'async_optimize', 'write_pdat',
         'confirm_overwrite', 'auto_save', 'export', 'import_',
         'parametric_project', 'cffio_options']

    single_precision_coordinates: single_precision_coordinates_cls = single_precision_coordinates_cls
    """
    single_precision_coordinates child of file.
    """
    binary_legacy_files: binary_legacy_files_cls = binary_legacy_files_cls
    """
    binary_legacy_files child of file.
    """
    cff_files: cff_files_cls = cff_files_cls
    """
    cff_files child of file.
    """
    convert_hanging_nodes_during_read: convert_hanging_nodes_during_read_cls = convert_hanging_nodes_during_read_cls
    """
    convert_hanging_nodes_during_read child of file.
    """
    async_optimize: async_optimize_cls = async_optimize_cls
    """
    async_optimize child of file.
    """
    write_pdat: write_pdat_cls = write_pdat_cls
    """
    write_pdat child of file.
    """
    confirm_overwrite: confirm_overwrite_cls = confirm_overwrite_cls
    """
    confirm_overwrite child of file.
    """
    auto_save: auto_save_cls = auto_save_cls
    """
    auto_save child of file.
    """
    export: export_cls = export_cls
    """
    export child of file.
    """
    import_: import__cls = import__cls
    """
    import_ child of file.
    """
    parametric_project: parametric_project_cls = parametric_project_cls
    """
    parametric_project child of file.
    """
    cffio_options: cffio_options_cls = cffio_options_cls
    """
    cffio_options child of file.
    """
    command_names = \
        ['define_macro', 'execute_macro', 'read_macros', 'read', 'read_case',
         'read_case_data', 'read_case_setting', 'read_data', 'read_mesh',
         'read_journal', 'start_journal', 'stop_journal', 'replace_mesh',
         'write', 'read_settings', 'read_field_functions', 'read_injections',
         'read_profile', 'read_pdf', 'read_isat_table', 'show_configuration',
         'stop_macro', 'start_transcript', 'stop_transcript',
         'data_file_options']

    define_macro: define_macro_cls = define_macro_cls
    """
    define_macro command of file.
    """
    execute_macro: execute_macro_cls = execute_macro_cls
    """
    execute_macro command of file.
    """
    read_macros: read_macros_cls = read_macros_cls
    """
    read_macros command of file.
    """
    read: read_cls = read_cls
    """
    read command of file.
    """
    read_case: read_case_cls = read_case_cls
    """
    read_case command of file.
    """
    read_case_data: read_case_data_cls = read_case_data_cls
    """
    read_case_data command of file.
    """
    read_case_setting: read_case_setting_cls = read_case_setting_cls
    """
    read_case_setting command of file.
    """
    read_data: read_data_cls = read_data_cls
    """
    read_data command of file.
    """
    read_mesh: read_mesh_cls = read_mesh_cls
    """
    read_mesh command of file.
    """
    read_journal: read_journal_cls = read_journal_cls
    """
    read_journal command of file.
    """
    start_journal: start_journal_cls = start_journal_cls
    """
    start_journal command of file.
    """
    stop_journal: stop_journal_cls = stop_journal_cls
    """
    stop_journal command of file.
    """
    replace_mesh: replace_mesh_cls = replace_mesh_cls
    """
    replace_mesh command of file.
    """
    write: write_cls = write_cls
    """
    write command of file.
    """
    read_settings: read_settings_cls = read_settings_cls
    """
    read_settings command of file.
    """
    read_field_functions: read_field_functions_cls = read_field_functions_cls
    """
    read_field_functions command of file.
    """
    read_injections: read_injections_cls = read_injections_cls
    """
    read_injections command of file.
    """
    read_profile: read_profile_cls = read_profile_cls
    """
    read_profile command of file.
    """
    read_pdf: read_pdf_cls = read_pdf_cls
    """
    read_pdf command of file.
    """
    read_isat_table: read_isat_table_cls = read_isat_table_cls
    """
    read_isat_table command of file.
    """
    show_configuration: show_configuration_cls = show_configuration_cls
    """
    show_configuration command of file.
    """
    stop_macro: stop_macro_cls = stop_macro_cls
    """
    stop_macro command of file.
    """
    start_transcript: start_transcript_cls = start_transcript_cls
    """
    start_transcript command of file.
    """
    stop_transcript: stop_transcript_cls = stop_transcript_cls
    """
    stop_transcript command of file.
    """
    data_file_options: data_file_options_cls = data_file_options_cls
    """
    data_file_options command of file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .initial_soc import initial_soc as initial_soc_cls
from .ref_capacity import ref_capacity as ref_capacity_cls
from .two_set_data import two_set_data as two_set_data_cls
from .data_type import data_type as data_type_cls
from .chen_rs import chen_rs as chen_rs_cls
from .chen_r1 import chen_r1 as chen_r1_cls
from .chen_c1 import chen_c1 as chen_c1_cls
from .chen_r2 import chen_r2 as chen_r2_cls
from .chen_c2 import chen_c2 as chen_c2_cls
from .chen_voc import chen_voc as chen_voc_cls
from .chen_rs_c import chen_rs_c as chen_rs_c_cls
from .chen_r1_c import chen_r1_c as chen_r1_c_cls
from .chen_c1_c import chen_c1_c as chen_c1_c_cls
from .chen_r2_c import chen_r2_c as chen_r2_c_cls
from .chen_c2_c import chen_c2_c as chen_c2_c_cls
from .chen_voc_c import chen_voc_c as chen_voc_c_cls
from .poly_rs import poly_rs as poly_rs_cls
from .poly_r1 import poly_r1 as poly_r1_cls
from .poly_c1 import poly_c1 as poly_c1_cls
from .poly_r2 import poly_r2 as poly_r2_cls
from .poly_c2 import poly_c2 as poly_c2_cls
from .poly_voc import poly_voc as poly_voc_cls
from .poly_rs_c import poly_rs_c as poly_rs_c_cls
from .poly_r1_c import poly_r1_c as poly_r1_c_cls
from .poly_c1_c import poly_c1_c as poly_c1_c_cls
from .poly_r2_c import poly_r2_c as poly_r2_c_cls
from .poly_c2_c import poly_c2_c as poly_c2_c_cls
from .poly_voc_c import poly_voc_c as poly_voc_c_cls
from .table_rs import table_rs as table_rs_cls
from .table_r1 import table_r1 as table_r1_cls
from .table_c1 import table_c1 as table_c1_cls
from .table_r2 import table_r2 as table_r2_cls
from .table_c2 import table_c2 as table_c2_cls
from .table_r3 import table_r3 as table_r3_cls
from .table_c3 import table_c3 as table_c3_cls
from .table_voc import table_voc as table_voc_cls
from .table_rs_c import table_rs_c as table_rs_c_cls
from .table_r1_c import table_r1_c as table_r1_c_cls
from .table_c1_c import table_c1_c as table_c1_c_cls
from .table_r2_c import table_r2_c as table_r2_c_cls
from .table_c2_c import table_c2_c as table_c2_c_cls
from .table_r3_c import table_r3_c as table_r3_c_cls
from .table_c3_c import table_c3_c as table_c3_c_cls
from .table_voc_c import table_voc_c as table_voc_c_cls
class ecm_model_settings(Group):
    """
    'ecm_model_settings' child.
    """

    fluent_name = "ecm-model-settings"

    child_names = \
        ['initial_soc', 'ref_capacity', 'two_set_data', 'data_type',
         'chen_rs', 'chen_r1', 'chen_c1', 'chen_r2', 'chen_c2', 'chen_voc',
         'chen_rs_c', 'chen_r1_c', 'chen_c1_c', 'chen_r2_c', 'chen_c2_c',
         'chen_voc_c', 'poly_rs', 'poly_r1', 'poly_c1', 'poly_r2', 'poly_c2',
         'poly_voc', 'poly_rs_c', 'poly_r1_c', 'poly_c1_c', 'poly_r2_c',
         'poly_c2_c', 'poly_voc_c', 'table_rs', 'table_r1', 'table_c1',
         'table_r2', 'table_c2', 'table_r3', 'table_c3', 'table_voc',
         'table_rs_c', 'table_r1_c', 'table_c1_c', 'table_r2_c', 'table_c2_c',
         'table_r3_c', 'table_c3_c', 'table_voc_c']

    initial_soc: initial_soc_cls = initial_soc_cls
    """
    initial_soc child of ecm_model_settings.
    """
    ref_capacity: ref_capacity_cls = ref_capacity_cls
    """
    ref_capacity child of ecm_model_settings.
    """
    two_set_data: two_set_data_cls = two_set_data_cls
    """
    two_set_data child of ecm_model_settings.
    """
    data_type: data_type_cls = data_type_cls
    """
    data_type child of ecm_model_settings.
    """
    chen_rs: chen_rs_cls = chen_rs_cls
    """
    chen_rs child of ecm_model_settings.
    """
    chen_r1: chen_r1_cls = chen_r1_cls
    """
    chen_r1 child of ecm_model_settings.
    """
    chen_c1: chen_c1_cls = chen_c1_cls
    """
    chen_c1 child of ecm_model_settings.
    """
    chen_r2: chen_r2_cls = chen_r2_cls
    """
    chen_r2 child of ecm_model_settings.
    """
    chen_c2: chen_c2_cls = chen_c2_cls
    """
    chen_c2 child of ecm_model_settings.
    """
    chen_voc: chen_voc_cls = chen_voc_cls
    """
    chen_voc child of ecm_model_settings.
    """
    chen_rs_c: chen_rs_c_cls = chen_rs_c_cls
    """
    chen_rs_c child of ecm_model_settings.
    """
    chen_r1_c: chen_r1_c_cls = chen_r1_c_cls
    """
    chen_r1_c child of ecm_model_settings.
    """
    chen_c1_c: chen_c1_c_cls = chen_c1_c_cls
    """
    chen_c1_c child of ecm_model_settings.
    """
    chen_r2_c: chen_r2_c_cls = chen_r2_c_cls
    """
    chen_r2_c child of ecm_model_settings.
    """
    chen_c2_c: chen_c2_c_cls = chen_c2_c_cls
    """
    chen_c2_c child of ecm_model_settings.
    """
    chen_voc_c: chen_voc_c_cls = chen_voc_c_cls
    """
    chen_voc_c child of ecm_model_settings.
    """
    poly_rs: poly_rs_cls = poly_rs_cls
    """
    poly_rs child of ecm_model_settings.
    """
    poly_r1: poly_r1_cls = poly_r1_cls
    """
    poly_r1 child of ecm_model_settings.
    """
    poly_c1: poly_c1_cls = poly_c1_cls
    """
    poly_c1 child of ecm_model_settings.
    """
    poly_r2: poly_r2_cls = poly_r2_cls
    """
    poly_r2 child of ecm_model_settings.
    """
    poly_c2: poly_c2_cls = poly_c2_cls
    """
    poly_c2 child of ecm_model_settings.
    """
    poly_voc: poly_voc_cls = poly_voc_cls
    """
    poly_voc child of ecm_model_settings.
    """
    poly_rs_c: poly_rs_c_cls = poly_rs_c_cls
    """
    poly_rs_c child of ecm_model_settings.
    """
    poly_r1_c: poly_r1_c_cls = poly_r1_c_cls
    """
    poly_r1_c child of ecm_model_settings.
    """
    poly_c1_c: poly_c1_c_cls = poly_c1_c_cls
    """
    poly_c1_c child of ecm_model_settings.
    """
    poly_r2_c: poly_r2_c_cls = poly_r2_c_cls
    """
    poly_r2_c child of ecm_model_settings.
    """
    poly_c2_c: poly_c2_c_cls = poly_c2_c_cls
    """
    poly_c2_c child of ecm_model_settings.
    """
    poly_voc_c: poly_voc_c_cls = poly_voc_c_cls
    """
    poly_voc_c child of ecm_model_settings.
    """
    table_rs: table_rs_cls = table_rs_cls
    """
    table_rs child of ecm_model_settings.
    """
    table_r1: table_r1_cls = table_r1_cls
    """
    table_r1 child of ecm_model_settings.
    """
    table_c1: table_c1_cls = table_c1_cls
    """
    table_c1 child of ecm_model_settings.
    """
    table_r2: table_r2_cls = table_r2_cls
    """
    table_r2 child of ecm_model_settings.
    """
    table_c2: table_c2_cls = table_c2_cls
    """
    table_c2 child of ecm_model_settings.
    """
    table_r3: table_r3_cls = table_r3_cls
    """
    table_r3 child of ecm_model_settings.
    """
    table_c3: table_c3_cls = table_c3_cls
    """
    table_c3 child of ecm_model_settings.
    """
    table_voc: table_voc_cls = table_voc_cls
    """
    table_voc child of ecm_model_settings.
    """
    table_rs_c: table_rs_c_cls = table_rs_c_cls
    """
    table_rs_c child of ecm_model_settings.
    """
    table_r1_c: table_r1_c_cls = table_r1_c_cls
    """
    table_r1_c child of ecm_model_settings.
    """
    table_c1_c: table_c1_c_cls = table_c1_c_cls
    """
    table_c1_c child of ecm_model_settings.
    """
    table_r2_c: table_r2_c_cls = table_r2_c_cls
    """
    table_r2_c child of ecm_model_settings.
    """
    table_c2_c: table_c2_c_cls = table_c2_c_cls
    """
    table_c2_c child of ecm_model_settings.
    """
    table_r3_c: table_r3_c_cls = table_r3_c_cls
    """
    table_r3_c child of ecm_model_settings.
    """
    table_c3_c: table_c3_c_cls = table_c3_c_cls
    """
    table_c3_c child of ecm_model_settings.
    """
    table_voc_c: table_voc_c_cls = table_voc_c_cls
    """
    table_voc_c child of ecm_model_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .all_var_num_of_bins import all_var_num_of_bins as all_var_num_of_bins_cls
class all_variables_number_of_bins(Command):
    """
    Set the number of bins to be used for ALL variables in the data reduction.
    
    Parameters
    ----------
        all_var_num_of_bins : int
            'all_var_num_of_bins' child.
    
    """

    fluent_name = "all-variables-number-of-bins"

    argument_names = \
        ['all_var_num_of_bins']

    all_var_num_of_bins: all_var_num_of_bins_cls = all_var_num_of_bins_cls
    """
    all_var_num_of_bins argument of all_variables_number_of_bins.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .leidenfrost_temp_postproc_enabled import leidenfrost_temp_postproc_enabled as leidenfrost_temp_postproc_enabled_cls
from .enabled_10 import enabled as enabled_cls
from .temp_limit_rel_to_boil_point import temp_limit_rel_to_boil_point as temp_limit_rel_to_boil_point_cls
class temperature_limiter(Group):
    """
    'temperature_limiter' child.
    """

    fluent_name = "temperature-limiter"

    child_names = \
        ['leidenfrost_temp_postproc_enabled', 'enabled',
         'temp_limit_rel_to_boil_point']

    leidenfrost_temp_postproc_enabled: leidenfrost_temp_postproc_enabled_cls = leidenfrost_temp_postproc_enabled_cls
    """
    leidenfrost_temp_postproc_enabled child of temperature_limiter.
    """
    enabled: enabled_cls = enabled_cls
    """
    enabled child of temperature_limiter.
    """
    temp_limit_rel_to_boil_point: temp_limit_rel_to_boil_point_cls = temp_limit_rel_to_boil_point_cls
    """
    temp_limit_rel_to_boil_point child of temperature_limiter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .embedded_face_zone import embedded_face_zone as embedded_face_zone_cls
from .floating_surface_name import floating_surface_name as floating_surface_name_cls
from .create_floating_disk import create_floating_disk as create_floating_disk_cls
class disk_id(Group):
    """
    Menu to define the disk face/surface name:
    
     - embedded-face-zone    : select embedded-face-zone name, 
     - floating-surface-name : select floating-surface-name, 
     - create-floating-disk  : create a floating-disk for the current rotor, 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "disk-id"

    child_names = \
        ['embedded_face_zone', 'floating_surface_name']

    embedded_face_zone: embedded_face_zone_cls = embedded_face_zone_cls
    """
    embedded_face_zone child of disk_id.
    """
    floating_surface_name: floating_surface_name_cls = floating_surface_name_cls
    """
    floating_surface_name child of disk_id.
    """
    command_names = \
        ['create_floating_disk']

    create_floating_disk: create_floating_disk_cls = create_floating_disk_cls
    """
    create_floating_disk command of disk_id.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .recirculation_outlet_child import recirculation_outlet_child

class recirculation_outlet(NamedObject[recirculation_outlet_child], _NonCreatableNamedObjectMixin[recirculation_outlet_child]):
    """
    'recirculation_outlet' child.
    """

    fluent_name = "recirculation-outlet"

    child_object_type: recirculation_outlet_child = recirculation_outlet_child
    """
    child_object_type of recirculation_outlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class sc_def_file_settings:
    fluent_name = ...
    child_names = ...
    enable_auto_creation_of_scp_file = ...
    command_names = ...

    def write_sc_file(self, file_name: str):
        """
        Write a Fluent Input File for System Coupling.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .wall_treatment import wall_treatment as wall_treatment_cls
from .user_defined import user_defined as user_defined_cls
from .enhanced_wall_treatment_options import enhanced_wall_treatment_options as enhanced_wall_treatment_options_cls
from .wall_omega_treatment import wall_omega_treatment as wall_omega_treatment_cls
class near_wall_treatment(Group):
    """
    'near_wall_treatment' child.
    """

    fluent_name = "near-wall-treatment"

    child_names = \
        ['wall_treatment', 'user_defined', 'enhanced_wall_treatment_options',
         'wall_omega_treatment']

    wall_treatment: wall_treatment_cls = wall_treatment_cls
    """
    wall_treatment child of near_wall_treatment.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of near_wall_treatment.
    """
    enhanced_wall_treatment_options: enhanced_wall_treatment_options_cls = enhanced_wall_treatment_options_cls
    """
    enhanced_wall_treatment_options child of near_wall_treatment.
    """
    wall_omega_treatment: wall_omega_treatment_cls = wall_omega_treatment_cls
    """
    wall_omega_treatment child of near_wall_treatment.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .change_numerics import change_numerics as change_numerics_cls
class non_conformal_interface_numerics(Group):
    """
    Setting non-conformal numerics options.
    """

    fluent_name = "non-conformal-interface-numerics"

    command_names = \
        ['change_numerics']

    change_numerics: change_numerics_cls = change_numerics_cls
    """
    change_numerics command of non_conformal_interface_numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .inside_1 import inside as inside_cls
from .outside import outside as outside_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['option', 'inside', 'outside']

    option: option_cls = option_cls
    """
    option child of options.
    """
    inside: inside_cls = inside_cls
    """
    inside child of options.
    """
    outside: outside_cls = outside_cls
    """
    outside child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class boundary_conditions:
    fluent_name = ...
    child_names = ...
    axis = ...
    degassing = ...
    exhaust_fan = ...
    fan = ...
    geometry = ...
    inlet_vent = ...
    intake_fan = ...
    interface = ...
    interior = ...
    mass_flow_inlet = ...
    mass_flow_outlet = ...
    network = ...
    network_end = ...
    outflow = ...
    outlet_vent = ...
    overset = ...
    periodic = ...
    porous_jump = ...
    pressure_far_field = ...
    pressure_inlet = ...
    pressure_outlet = ...
    radiator = ...
    rans_les_interface = ...
    recirculation_inlet = ...
    recirculation_outlet = ...
    shadow = ...
    symmetry = ...
    velocity_inlet = ...
    wall = ...
    command_names = ...

    def change_type(self, zone_list: List[str], new_type: str):
        """
        'change_type' command.
        
        Parameters
        ----------
            zone_list : typing.List[str]
                'zone_list' child.
            new_type : str
                'new_type' child.
        
        """

    def slit_face_zone(self, zone_id: int):
        """
        Slit a two-sided wall into two connected wall zones.
        
        Parameters
        ----------
            zone_id : int
                'zone_id' child.
        
        """

    def slit_interior_between_diff_solids(self, ):
        """
        Slit interior created between different solids into coupled walls.
        """

    def create_all_shell_threads(self, ):
        """
        Mark all finite thickness wall for shell creation. Shell zones will be created at the start of iterations.
        """

    def recreate_all_shells(self, ):
        """
        Create shell on all the walls where which were deleted using the command delete-all-shells.
        """

    def delete_all_shells(self, ):
        """
        'delete_all_shells' command.
        """

    def orient_face_zone(self, face_zone_id: int):
        """
        Orient the face zone.
        
        Parameters
        ----------
            face_zone_id : int
                'face_zone_id' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cumulation_curve(Boolean):
    """
    Compute a cumulative curve for sampling variable or correlation variable when correlation? was specified.
    """

    fluent_name = "cumulation-curve?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .histogram import histogram as histogram_cls
from .sample_trajectories import sample_trajectories as sample_trajectories_cls
from .summary import summary as summary_cls
from .extended_summary import extended_summary as extended_summary_cls
from .zone_summaries_per_injection import zone_summaries_per_injection as zone_summaries_per_injection_cls
class discrete_phase(Group):
    """
    'discrete_phase' child.
    """

    fluent_name = "discrete-phase"

    child_names = \
        ['histogram', 'sample_trajectories']

    histogram: histogram_cls = histogram_cls
    """
    histogram child of discrete_phase.
    """
    sample_trajectories: sample_trajectories_cls = sample_trajectories_cls
    """
    sample_trajectories child of discrete_phase.
    """
    command_names = \
        ['summary', 'extended_summary', 'zone_summaries_per_injection']

    summary: summary_cls = summary_cls
    """
    summary command of discrete_phase.
    """
    extended_summary: extended_summary_cls = extended_summary_cls
    """
    extended_summary command of discrete_phase.
    """
    zone_summaries_per_injection: zone_summaries_per_injection_cls = zone_summaries_per_injection_cls
    """
    zone_summaries_per_injection command of discrete_phase.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class extrapolate_eqn_vars:
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def list_properties(self, object_name: str):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_name : str
                'object_name' child.
        
        """

    def duplicate(self, from_: str, to: str):
        """
        'duplicate' command.
        
        Parameters
        ----------
            from_ : str
                'from' child.
            to : str
                'to' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



"""Wrappers over StateEngine based datamodel gRPC service of Fluent."""
from enum import Enum
import functools
import itertools
import logging
from typing import Any, Callable, Iterator, NoReturn, Optional, Sequence, Union

from google.protobuf.json_format import MessageToDict, ParseDict
import grpc

from ansys.api.fluent.v0 import datamodel_se_pb2 as DataModelProtoModule
from ansys.api.fluent.v0 import datamodel_se_pb2_grpc as DataModelGrpcModule
from ansys.api.fluent.v0.variant_pb2 import Variant
import ansys.fluent.core as pyfluent
from ansys.fluent.core.data_model_cache import DataModelCache, NameKey
from ansys.fluent.core.exceptions import InvalidArgument
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import (
    BatchInterceptor,
    ErrorStateInterceptor,
    TracingInterceptor,
    WrapApiCallInterceptor,
)
from ansys.fluent.core.services.streaming import StreamingService

Path = list[tuple[str, str]]
_TValue = Union[None, bool, int, float, str, Sequence["_TValue"], dict[str, "_TValue"]]

logger: logging.Logger = logging.getLogger("pyfluent.datamodel")

member_specs_oneof_fields = [
    x.name
    for x in DataModelProtoModule.MemberSpecs.DESCRIPTOR.oneofs_by_name["as"].fields
]


def _get_value_from_message_dict(
    d: dict[str, Any], key: list[Union[str, Sequence[str]]]
):
    """Get value from a protobuf message dict."""
    for k in key:
        if isinstance(k, str):
            d = d[k]
        else:
            d = next(filter(None, (d.get(x) for x in k)))
    return d


class InvalidNamedObject(RuntimeError):
    """Provides the error when the object is not a named object."""

    def __init__(self, class_name):
        super().__init__(f"{class_name} is not a named object class.")


class SubscribeEventError(RuntimeError):
    """Provides the error when server fails to subscribe from event."""

    def __init__(self, request):
        super().__init__(f"Failed to subscribe event: {request}!")


class UnsubscribeEventError(RuntimeError):
    """Provides the error when server fails to unsubscribe from event."""

    def __init__(self, request):
        super().__init__(f"Failed to unsubscribe event: {request}!")


class Attribute(Enum):
    """Contains the standard names of data model attributes associated with the data
    model service."""

    IS_ACTIVE: str = "isActive"
    EXPOSURE_LEVEL: str = "exposureLevel"
    IS_READ_ONLY: str = "isReadOnly"
    DEFAULT: str = "default"
    FORCE_DEFAULT: str = "forceDefault"
    MIN: str = "min"
    MAX: str = "max"
    ALLOWED_VALUES: str = "allowedValues"
    EXCLUDED_VALUES: str = "excludedValues"
    MIN_LENGTH: str = "minLength"
    MAX_LENGTH: str = "maxLength"
    ERROR_STATUS: str = "errorStatus"
    USER_ERROR_STATUS: str = "userErrorStatus"
    MEMBERS: str = "members"
    DISPLAY_TEXT: str = "displayText"
    NAMES: str = "__names__"
    INTERNAL_NAMES: str = "__ids__"
    PATHS: str = "__paths__"
    ROOT_ID: str = "__root__"
    NAME: str = "_name_"
    REFERENCE_PATH: str = "referencePath"
    ARGUMENTS: str = "arguments"
    TOOL_TIP: str = "toolTip"
    SHOW_AT_PARENT_NODE: str = "showAtParentNode"
    WIDGET_TYPE: str = "widgetType"
    ECHO_MODE: str = "echoMode"
    IS_TREE_NODE: str = "isTreeNode"
    MIGRATION: str = "migration"
    DEPRECATED_VERSION: str = "deprecatedVersion"


class DatamodelServiceImpl:
    """Wraps the StateEngine-based datamodel gRPC service of Fluent."""

    def __init__(
        self, channel: grpc.Channel, metadata: list[tuple[str, str]], fluent_error_state
    ) -> None:
        """__init__ method of DatamodelServiceImpl class."""
        intercept_channel = grpc.intercept_channel(
            channel,
            ErrorStateInterceptor(fluent_error_state),
            TracingInterceptor(),
            BatchInterceptor(),
            WrapApiCallInterceptor(),
        )
        self._stub = DataModelGrpcModule.DataModelStub(intercept_channel)
        self._metadata = metadata

    @catch_grpc_error
    def initialize_datamodel(
        self, request: DataModelProtoModule.InitDatamodelRequest
    ) -> DataModelProtoModule.InitDatamodelResponse:
        """initDatamodel RPC of DataModel service."""
        return self._stub.initDatamodel(request, metadata=self._metadata)

    @catch_grpc_error
    def get_attribute_value(
        self, request: DataModelProtoModule.GetAttributeValueRequest
    ) -> DataModelProtoModule.GetAttributeValueResponse:
        """getAttributeValue RPC of DataModel service."""
        return self._stub.getAttributeValue(request, metadata=self._metadata)

    @catch_grpc_error
    def get_state(
        self, request: DataModelProtoModule.GetStateRequest
    ) -> DataModelProtoModule.GetStateResponse:
        """getState RPC of DataModel service."""
        return self._stub.getState(request, metadata=self._metadata)

    @catch_grpc_error
    def rename(
        self, request: DataModelProtoModule.RenameRequest
    ) -> DataModelProtoModule.RenameResponse:
        """getState RPC of DataModel service."""
        return self._stub.rename(request, metadata=self._metadata)

    @catch_grpc_error
    def get_object_names(
        self, request: DataModelProtoModule.GetObjectNamesRequest
    ) -> DataModelProtoModule.GetObjectNamesResponse:
        """getState RPC of DataModel service."""
        return self._stub.getObjectNames(request, metadata=self._metadata)

    @catch_grpc_error
    def delete_child_objects(
        self, request: DataModelProtoModule.DeleteChildObjectsRequest
    ) -> DataModelProtoModule.DeleteChildObjectsResponse:
        """getState RPC of DataModel service."""
        return self._stub.deleteChildObjects(request, metadata=self._metadata)

    @catch_grpc_error
    def set_state(
        self, request: DataModelProtoModule.SetStateRequest
    ) -> DataModelProtoModule.SetStateResponse:
        """setState RPC of DataModel service."""
        return self._stub.setState(request, metadata=self._metadata)

    @catch_grpc_error
    def fix_state(
        self, request: DataModelProtoModule.FixStateRequest
    ) -> DataModelProtoModule.FixStateResponse:
        """setState RPC of DataModel service."""
        return self._stub.fixState(request, metadata=self._metadata)

    @catch_grpc_error
    def update_dict(
        self, request: DataModelProtoModule.UpdateDictRequest
    ) -> DataModelProtoModule.UpdateDictResponse:
        """updateDict RPC of DataModel service."""
        return self._stub.updateDict(request, metadata=self._metadata)

    @catch_grpc_error
    def delete_object(
        self, request: DataModelProtoModule.DeleteObjectRequest
    ) -> DataModelProtoModule.DeleteObjectResponse:
        """deleteObject RPC of DataModel service."""
        return self._stub.deleteObject(request, metadata=self._metadata)

    @catch_grpc_error
    def execute_command(
        self, request: DataModelProtoModule.ExecuteCommandRequest
    ) -> DataModelProtoModule.ExecuteCommandResponse:
        """executeCommand RPC of DataModel service."""
        logger.debug(f"Command: {request.command}")
        return self._stub.executeCommand(request, metadata=self._metadata)

    @catch_grpc_error
    def execute_query(
        self, request: DataModelProtoModule.ExecuteQueryRequest
    ) -> DataModelProtoModule.ExecuteQueryResponse:
        """ExecuteQuery rpc of DataModel service."""
        logger.debug(f"Query: {request.query}")
        return self._stub.executeQuery(request, metadata=self._metadata)

    @catch_grpc_error
    def create_command_arguments(
        self, request: DataModelProtoModule.CreateCommandArgumentsRequest
    ) -> DataModelProtoModule.CreateCommandArgumentsResponse:
        """createCommandArguments RPC of DataModel service."""
        return self._stub.createCommandArguments(request, metadata=self._metadata)

    # pylint: disable=missing-raises-doc
    def delete_command_arguments(
        self, request: DataModelProtoModule.DeleteCommandArgumentsRequest
    ) -> DataModelProtoModule.DeleteCommandArgumentsResponse:
        """deleteCommandArguments RPC of DataModel service."""
        try:
            return self._stub.deleteCommandArguments(request, metadata=self._metadata)
        except grpc.RpcError as ex:
            raise RuntimeError(
                f"The following exception was caught\n {ex.details()}\n "
                "while deleting a command instance. Command instancing is"
                "supported from Ansys 2023R2 onward."
            ) from None

    @catch_grpc_error
    def get_specs(
        self, request: DataModelProtoModule.GetSpecsRequest
    ) -> DataModelProtoModule.GetSpecsResponse:
        """getSpecs RPC of DataModel service."""
        return self._stub.getSpecs(request, metadata=self._metadata)

    @catch_grpc_error
    def get_static_info(
        self, request: DataModelProtoModule.GetStaticInfoRequest
    ) -> DataModelProtoModule.GetStaticInfoResponse:
        """getStaticInfo RPC of DataModel service."""
        return self._stub.getStaticInfo(request, metadata=self._metadata)

    @catch_grpc_error
    def subscribe_events(
        self, request: DataModelProtoModule.SubscribeEventsRequest
    ) -> DataModelProtoModule.SubscribeEventsResponse:
        """subscribeEvents RPC of DataModel service."""
        return self._stub.subscribeEvents(request, metadata=self._metadata)

    @catch_grpc_error
    def unsubscribe_events(
        self, request: DataModelProtoModule.UnsubscribeEventsRequest
    ) -> DataModelProtoModule.UnsubscribeEventsResponse:
        """unsubscribeEvents RPC of DataModel service."""
        return self._stub.unsubscribeEvents(request, metadata=self._metadata)


def _convert_value_to_variant(val: _TValue, var: Variant) -> None:
    """Convert a Python data type to Fluent's variant type."""
    if isinstance(val, bool):
        var.bool_state = val
    elif isinstance(val, int):
        var.int64_state = val
    elif isinstance(val, float):
        var.double_state = val
    elif isinstance(val, str):
        var.string_state = val
    elif isinstance(val, (list, tuple)):
        var.variant_vector_state.SetInParent()
        for item in val:
            item_var = var.variant_vector_state.item.add()
            _convert_value_to_variant(item, item_var)
    elif isinstance(val, dict):
        for k, v in val.items():
            _convert_value_to_variant(v, var.variant_map_state.item[k])


def _convert_variant_to_value(var: Variant) -> _TValue:
    """Convert Fluent's variant type to a Python data type."""
    if var.HasField("bool_state"):
        return var.bool_state
    elif var.HasField("int64_state"):
        return var.int64_state
    elif var.HasField("double_state"):
        return var.double_state
    elif var.HasField("string_state"):
        return var.string_state
    elif var.HasField("bool_vector_state"):
        return var.bool_vector_state.item
    elif var.HasField("int64_vector_state"):
        return var.int64_vector_state.item
    elif var.HasField("double_vector_state"):
        return var.double_vector_state.item
    elif var.HasField("string_vector_state"):
        return var.string_vector_state.item
    elif var.HasField("variant_vector_state"):
        val = []
        for item in var.variant_vector_state.item:
            val.append(_convert_variant_to_value(item))
        return val
    elif var.HasField("variant_map_state"):
        val = {}
        for k, v in var.variant_map_state.item.items():
            val[k] = _convert_variant_to_value(v)
        return val


class EventSubscription:
    """EventSubscription class for any datamodel event."""

    def __init__(
        self,
        service,
        request_dict: dict[str, Any],
    ) -> None:
        """Subscribe to a datamodel event.

        Raises
        ------
        SubscribeEventError
            If server fails to subscribe from event.
        """
        self._service = service
        response = service.subscribe_events(request_dict)
        response = response[0]
        if response["status"] != DataModelProtoModule.STATUS_SUBSCRIBED:
            raise SubscribeEventError(request_dict)
        self.status = response["status"]
        self.tag = response["tag"]
        self._service.events[self.tag] = self

    def unsubscribe(self) -> None:
        """Unsubscribe the datamodel event.

        Raises
        ------
        UnsubscribeEventError
            If server fails to unsubscribe from event.
        """
        if self.status == DataModelProtoModule.STATUS_SUBSCRIBED:
            self._service.event_streaming.unregister_callback(self.tag)
            response = self._service.unsubscribe_events([self.tag])
            response = response[0]
            if response["status"] != DataModelProtoModule.STATUS_UNSUBSCRIBED:
                raise UnsubscribeEventError(self.tag)
            self.status = response["status"]
            self._service.events.pop(self.tag, None)

    def __del__(self) -> None:
        """Unsubscribe the datamodel event."""
        self.unsubscribe()


class DatamodelService(StreamingService):
    """Pure Python wrapper of DatamodelServiceImpl."""

    def __init__(
        self, channel: grpc.Channel, metadata: list[tuple[str, str]], fluent_error_state
    ) -> None:
        """__init__ method of DatamodelService class."""
        self._impl = DatamodelServiceImpl(channel, metadata, fluent_error_state)
        super().__init__(
            stub=self._impl._stub,
            metadata=metadata,
        )
        self.event_streaming = None
        self.events = {}

    def get_attribute_value(self, rules: str, path: str, attribute: str) -> _TValue:
        request = DataModelProtoModule.GetAttributeValueRequest(
            rules=rules, path=path, attribute=attribute
        )
        response = self._impl.get_attribute_value(request)
        return _convert_variant_to_value(response.result)

    def get_state(self, rules: str, path: str) -> _TValue:
        request = DataModelProtoModule.GetStateRequest(rules=rules, path=path)
        response = self._impl.get_state(request)
        return _convert_variant_to_value(response.state)

    def get_object_names(self, rules, path):
        request = DataModelProtoModule.GetStateRequest()
        request.rules = rules
        request.path = convert_path_to_se_path(path)
        response = self._impl.get_object_names(request)
        return response.names

    def rename(self, rules, path, new_name) -> None:
        request = DataModelProtoModule.RenameRequest()
        request.rules = rules
        request.path = convert_path_to_se_path(path)
        request.new_name = new_name
        request.wait = True
        self._impl.rename(request)

    def delete_child_objects(self, rules, path, child_names) -> None:
        request = DataModelProtoModule.DeleteChildObjectsRequest()
        request.rules = rules
        request.path = path
        for name in child_names:
            request.child_names.names.append(name)
        request.wait = True
        self._impl.delete_child_objects(request)

    def delete_all_child_objects(self, rules, path):
        request = DataModelProtoModule.DeleteChildObjectsRequest()
        request.rules = rules
        request.path = path
        request.delete_all = True
        request.wait = True
        self._impl.delete_child_objects(request)

    def set_state(self, rules: str, path: str, state: _TValue) -> None:
        request = DataModelProtoModule.SetStateRequest(
            rules=rules, path=path, wait=True
        )
        _convert_value_to_variant(state, request.state)
        self._impl.set_state(request)

    def fix_state(self, rules, path) -> None:
        request = DataModelProtoModule.FixStateRequest()
        request.rules = rules
        request.path = convert_path_to_se_path(path)
        self._impl.fix_state(request)

    def update_dict(
        self, rules: str, path: str, dict_state: dict[str, _TValue]
    ) -> None:
        request = DataModelProtoModule.UpdateDictRequest(
            rules=rules, path=path, wait=True
        )
        _convert_value_to_variant(dict_state, request.dicttomerge)
        self._impl.update_dict(request)

    def delete_object(self, rules: str, path: str) -> None:
        request = DataModelProtoModule.DeleteObjectRequest(
            rules=rules, path=path, wait=True
        )
        self._impl.delete_object(request)

    def execute_command(
        self, rules: str, path: str, command: str, args: dict[str, _TValue]
    ) -> _TValue:
        request = DataModelProtoModule.ExecuteCommandRequest(
            rules=rules, path=path, command=command, wait=True
        )
        _convert_value_to_variant(args, request.args)
        response = self._impl.execute_command(request)
        return _convert_variant_to_value(response.result)

    def execute_query(
        self, rules: str, path: str, query: str, args: dict[str, _TValue]
    ) -> _TValue:
        request = DataModelProtoModule.ExecuteQueryRequest(
            rules=rules, path=path, query=query
        )
        _convert_value_to_variant(args, request.args)
        response = self._impl.execute_query(request)
        return _convert_variant_to_value(response.result)

    def create_command_arguments(self, rules: str, path: str, command: str) -> str:
        request = DataModelProtoModule.CreateCommandArgumentsRequest(
            rules=rules, path=path, command=command
        )
        response = self._impl.create_command_arguments(request)
        return response.commandid

    def delete_command_arguments(
        self, rules: str, path: str, command: str, commandid: str
    ) -> None:
        request = DataModelProtoModule.DeleteCommandArgumentsRequest(
            rules=rules, path=path, command=command, commandid=commandid
        )
        self._impl.delete_command_arguments(request)

    def get_specs(
        self,
        rules: str,
        path: str,
    ) -> dict[str, Any]:
        request = DataModelProtoModule.GetSpecsRequest(
            rules=rules,
            path=path,
        )
        return MessageToDict(
            self._impl.get_specs(request).member, use_integers_for_enums=True
        )

    def get_static_info(self, rules: str) -> dict[str, Any]:
        request = DataModelProtoModule.GetStaticInfoRequest(rules=rules)
        return MessageToDict(
            self._impl.get_static_info(request).info, use_integers_for_enums=True
        )

    def subscribe_events(self, request_dict: dict[str, Any]) -> dict[str, Any]:
        request = DataModelProtoModule.SubscribeEventsRequest()
        ParseDict(request_dict, request)
        return [
            MessageToDict(x, use_integers_for_enums=True)
            for x in self._impl.subscribe_events(request).response
        ]

    def unsubscribe_events(self, tags: list[str]) -> dict[str, Any]:
        request = DataModelProtoModule.UnsubscribeEventsRequest()
        request.tag[:] = tags
        return [
            MessageToDict(x, use_integers_for_enums=True)
            for x in self._impl.unsubscribe_events(request).response
        ]

    def unsubscribe_all_events(self) -> None:
        """Unsubscribe all subscribed events."""
        for event in list(self.events.values()):
            event.unsubscribe()
        self.events.clear()

    def add_on_child_created(
        self, rules: str, path: str, child_type: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "createdEventRequest": {
                        "parentpath": path,
                        "childtype": child_type,
                    },
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_deleted(
        self, rules: str, path: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "deletedEventRequest": {"path": path},
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_changed(
        self, rules: str, path: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "modifiedEventRequest": {"path": path},
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_affected(
        self, rules: str, path: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "affectedEventRequest": {"path": path},
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_affected_at_type_path(
        self, rules: str, path: str, child_type: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "affectedEventRequest": {
                        "path": path,
                        "subtype": child_type,
                    },
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_command_executed(
        self, rules: str, path: str, command: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "commandExecutedEventRequest": {
                        "path": path,
                        "command": command,
                    },
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_attribute_changed(
        self, rules: str, path: str, attribute: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "attributeChangedEventRequest": {
                        "path": path,
                        "attribute": attribute,
                    },
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription

    def add_on_command_attribute_changed(
        self, rules: str, path: str, command: str, attribute: str, obj, cb: Callable
    ) -> EventSubscription:
        request_dict = {
            "eventrequest": [
                {
                    "rules": rules,
                    "commandAttributeChangedEventRequest": {
                        "path": path,
                        "command": command,
                        "attribute": attribute,
                    },
                }
            ]
        }
        subscription = EventSubscription(self, request_dict)
        self.event_streaming.register_callback(subscription.tag, obj, cb)
        return subscription


def convert_path_to_se_path(path: Path) -> str:
    """Convert a path structure to a StateEngine path.

    Parameters
    ----------
    path : Path
        Path structure.

    Returns
    -------
    str
        stateengine path
    """
    se_path = ""
    for comp in path:
        se_path += "/" + comp[0]
        if comp[1]:
            se_path += ":" + comp[1]
    return se_path


class PyCallableStateObject:
    """Any object which can be called to get its state.

    Methods
    -------
    __call__()
        Get the state of the current object.
    """

    def __call__(self, *args, **kwds) -> Any:
        return self.get_state()


class PyStateContainer(PyCallableStateObject):
    """Object class using StateEngine based DatamodelService as backend. Use this class
    instead of directly calling DatamodelService's method.

    Methods
    -------
    get_attr(attrib)
        Get the attribute value of the current object.
    getAttribValue(attrib)
        Get the attribute value of the current object.
        (This method is the same as the get_attr(attrib)
        method.)
    get_state()
        Get the state of the current object.
    getState()
        Deprecated camel case alias of get_state.
    set_state()
        Set the state of the current object.
    setState()
        Deprecated camel case alias of set_state.
    __call__()
        Set the state of the current object if state is provided else get its state.
    """

    def __init__(
        self, service: DatamodelService, rules: str, path: Optional[Path] = None
    ) -> None:
        """__init__ method of PyStateContainer class."""
        super().__init__()
        self.service: DatamodelService = service
        self.rules = rules
        if path is None:
            self.path = []
        else:
            self.path = path
        self.cached_attrs = {}

    def get_remote_state(self) -> Any:
        """Get state of the current object."""
        return self.service.get_state(self.rules, convert_path_to_se_path(self.path))

    def get_state(self) -> Any:
        if pyfluent.DATAMODEL_USE_STATE_CACHE:
            state = DataModelCache.get_state(self.rules, self, NameKey.DISPLAY)
            if DataModelCache.is_unassigned(state):
                state = self.get_remote_state()
        else:
            state = self.get_remote_state()
        return state

    getState = get_state

    def fix_state(self) -> None:
        self.service.fix_state(self.rules, self.path)

    fixState = fix_state

    def set_state(self, state: Optional[Any] = None, **kwargs) -> None:
        """Set state of the current object."""
        self.service.set_state(
            self.rules, convert_path_to_se_path(self.path), kwargs or state
        )

    setState = set_state

    def _get_remote_attr(self, attrib: str) -> Any:
        return self.service.get_attribute_value(
            self.rules, convert_path_to_se_path(self.path), attrib
        )

    def _get_cached_attr(self, attrib: str) -> Any:
        cached_val = self.cached_attrs.get(attrib)
        if cached_val is None:
            cached_val = self._get_remote_attr(attrib)
            try:  # will fail for Fluent 23.1 or before
                self.add_on_attribute_changed(
                    attrib,
                    functools.partial(dict.__setitem__, self.cached_attrs, attrib),
                )
                self.cached_attrs[attrib] = cached_val
            except Exception:
                pass
        return cached_val

    def get_attr(self, attrib: str) -> Any:
        """Get attribute value of the current object.

        Parameters
        ----------
        attrib : str
            Name of the attribute.

        Returns
        -------
        Any
            Value of the attribute.
        """
        if pyfluent.DATAMODEL_USE_ATTR_CACHE:
            return self._get_cached_attr(attrib)
        return self._get_remote_attr(attrib)

    getAttribValue = get_attr

    def is_active(self) -> bool:
        """Returns true if the object is active."""
        return true_if_none(self.get_attr(Attribute.IS_ACTIVE.value))

    def is_read_only(self) -> bool:
        """Checks whether the object is read only."""
        return false_if_none(self.get_attr(Attribute.IS_READ_ONLY.value))

    def help(self) -> None:
        """Print help string."""
        response = self.service.get_specs(
            self.rules, convert_path_to_se_path(self.path)
        )
        help_string = _get_value_from_message_dict(
            response, [member_specs_oneof_fields, "common", "helpstring"]
        )
        print(help_string)

    def __call__(self, *args, **kwargs) -> Any:
        if kwargs:
            self.set_state(kwargs)
        elif args:
            self.set_state(args)
        else:
            return self.get_state()

    docstring = None

    def add_on_attribute_changed(
        self, attribute: str, cb: Callable
    ) -> EventSubscription:
        """Register a callback for when an attribute is changed.

        Parameters
        ----------
        attribute : str
            attribute name
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_attribute_changed(
            self.rules, convert_path_to_se_path(self.path), attribute, self, cb
        )

    def add_on_command_attribute_changed(
        self, command: str, attribute: str, cb: Callable
    ) -> EventSubscription:
        """Register a callback for when an attribute is changed.

        Parameters
        ----------
        command : str
            command name
        attribute : str
            attribute name
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_command_attribute_changed(
            self.rules, convert_path_to_se_path(self.path), command, attribute, self, cb
        )


class PyMenu(PyStateContainer):
    """Object class using StateEngine based DatamodelService as backend. Use this class
    instead of directly calling DatamodelService's method.

    Methods
    -------
    __setattr__(name, value)
        Set state of the child object
    rename(new_name)
    name()
    create_command_arguments(command)
    """

    def __init__(
        self, service: DatamodelService, rules: str, path: Optional[Path] = None
    ) -> None:
        """__init__ method of PyMenu class."""
        super().__init__(service, rules, path)

    def __setattr__(self, name: str, value: Any) -> None:
        """Set state of the child object.

        Parameters
        ----------
        name : str
            child object name
        value : Any
            state
        """
        if hasattr(self, name) and isinstance(getattr(self, name), PyStateContainer):
            getattr(self, name).set_state(value)
        else:
            super().__setattr__(name, value)

    def name(self) -> str:
        """Get the name of the named object.

        Returns
        -------
        str
            name

        Raises
        ------
        InvalidNamedObject
            If the object is not a named object.
        """
        try:
            return self._name_()
        except AttributeError:
            raise InvalidNamedObject(self.__class__.__name__)

    def _raise_method_not_yet_implemented_exception(self) -> NoReturn:
        raise AttributeError("This method is yet to be implemented in pyfluent.")

    def delete_child(self) -> None:
        self._raise_method_not_yet_implemented_exception()

    def rename(self, new_name: str) -> None:
        """Rename the named object.

        Parameters
        ----------
        new_name : str
            New name for the object.
        """
        self.service.rename(self.rules, self.path, new_name)

    def delete_child_objects(self, obj_type: str, child_names: list[str]):
        """Delete the named objects in 'child_names' from  the container..

        Parameters
        ----------
        obj_type: str
            Type of the named object container.
        child_names : List[str]
            List of named objects.
        """
        child_obj_path = convert_path_to_se_path(self.path) + "/" + obj_type
        self.service.delete_child_objects(self.rules, child_obj_path, child_names)

    deleteChildObjects = delete_child_objects

    def delete_all_child_objects(self, obj_type):
        """Delete all the named objects in the container.

         Parameters
        ----------
        obj_type: str
            Type of the named object container.
        """
        child_obj_path = convert_path_to_se_path(self.path) + "/" + obj_type
        self.service.delete_all_child_objects(self.rules, child_obj_path)

    deleteAllChildObjects = delete_all_child_objects

    def create_command_arguments(self, command: str) -> str:
        """Create command arguments.

        Parameters
        ----------
        command : str
            Command name

        Returns
        -------
        str
            Command ID
        """
        return self.service.create_command_arguments(
            self.rules, convert_path_to_se_path(self.path), command
        )

    def add_on_child_created(self, child_type: str, cb: Callable) -> EventSubscription:
        """Register a callback for when a child object is created.

        Parameters
        ----------
        child_type : str
            Type of the child object
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_child_created(
            self.rules, convert_path_to_se_path(self.path), child_type, self, cb
        )

    def add_on_deleted(self, cb: Callable) -> EventSubscription:
        """Register a callback for when the object is deleted.

        Parameters
        ----------
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_deleted(
            self.rules, convert_path_to_se_path(self.path), self, cb
        )

    def add_on_changed(self, cb: Callable) -> EventSubscription:
        """Register a callback for when the object is modified.

        Parameters
        ----------
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_changed(
            self.rules, convert_path_to_se_path(self.path), self, cb
        )

    def add_on_affected(self, cb: Callable) -> EventSubscription:
        """Register a callback for when the object is affected.

        Parameters
        ----------
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_affected(
            self.rules, convert_path_to_se_path(self.path), self, cb
        )

    def add_on_affected_at_type_path(
        self, child_type: str, cb: Callable
    ) -> EventSubscription:
        """Register a callback for when the object is affected at child type.

        Parameters
        ----------
        child_type : str
            child type
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_affected_at_type_path(
            self.rules, convert_path_to_se_path(self.path), child_type, self, cb
        )

    def add_on_command_executed(self, command: str, cb: Callable) -> EventSubscription:
        """Register a callback for when a command is executed.

        Parameters
        ----------
        command : str
            command name
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_command_executed(
            self.rules, convert_path_to_se_path(self.path), command, self, cb
        )


class PyParameter(PyStateContainer):
    """Object class using StateEngine based DatamodelService as backend.

    Use this class instead of directly calling DatamodelService's method.
    """

    def default_value(self) -> Any:
        """Get default value of the parameter."""
        return self.get_attr(Attribute.DEFAULT.value)

    def add_on_changed(self, cb: Callable) -> EventSubscription:
        """Register a callback for when the object is modified.

        Parameters
        ----------
        cb : Callable
            Callback function

        Returns
        -------
        EventSubscription
            EventSubscription instance which can be used to unregister the callback
        """
        return self.service.add_on_changed(
            self.rules, convert_path_to_se_path(self.path), self, cb
        )


def _bool_value_if_none(val: Optional[bool], default: bool) -> bool:
    if isinstance(val, bool) or val is None:
        return default if val is None else val
    raise TypeError(f"{val} should be a bool or None")


def true_if_none(val: Optional[bool]) -> bool:
    """Returns true if 'val' is true or None, else returns false."""
    return _bool_value_if_none(val, default=True)


def false_if_none(val: Optional[bool]) -> bool:
    """Returns false if 'val' is false or None, else returns true."""
    return _bool_value_if_none(val, default=False)


class PyTextual(PyParameter):
    """Provides interface for textual parameters."""

    def allowed_values(self) -> list[str]:
        return self.get_attr(Attribute.ALLOWED_VALUES.value)


class PyNumerical(PyParameter):
    """Provides interface for numerical parameters."""

    def min(self) -> float:
        """Minimum value of the numerical parameter."""
        return self.get_attr(Attribute.MIN.value)

    def max(self) -> float:
        """Maximum value of the numerical parameter."""
        return self.get_attr(Attribute.MAX.value)


class PyDictionary(PyParameter):
    """Provides interface for dictionaries.

    Methods
    -------
    update_dict(dict_state)
        Update the state of the current object if the current object
        is a Dict in the data model, else throws RuntimeError
        (currently not showing up in Python). Update is executed according
        to dict.update semantics
    updateDict(dict_state)
        Update the state of the current object if the current object
        is a Dict in the data model, else throws RuntimeError
        (currently not showing up in Python). Update is executed according
        to dict.update semantics (same as update_dict(dict_state))]
    """

    def update_dict(self, dict_state: dict[str, Any]) -> None:
        """Update the state of the current object if the current object is a Dict in the
        data model, else throws RuntimeError (currently not showing up in Python).
        Update is executed according to dict.update semantics.

        Parameters
        ----------
        dict_state : dict[str, Any]
            Incoming dict state
        """
        self.service.update_dict(
            self.rules, convert_path_to_se_path(self.path), dict_state
        )

    updateDict = update_dict


class PyNamedObjectContainer:
    """Container class using the StateEngine-based DatamodelService as the backend. Use
    this class instead of directly calling the DatamodelService's method.

    Methods
    -------
    __len__()
        Return a count of the child objects.
    __iter__()
        Return the next child object.
    __getitem__(key)
        Return the child object by key.
    __setitem__(key, value)
        Set the state of the child object by name.
    __delitem__(key)
        Delete the child object by name.
    """

    def __init__(
        self, service: DatamodelService, rules: str, path: Optional[Path] = None
    ) -> None:
        """__init__ method of PyNamedObjectContainer class."""
        self.service = service
        self.rules = rules
        if path is None:
            self.path = []
        else:
            self.path = path

    def _get_child_object_names(self) -> list[str]:
        parent_path = self.path[0:-1]
        child_type_suffix = self.path[-1][0] + ":"
        response = self.service.get_specs(
            self.rules, convert_path_to_se_path(parent_path)
        )
        child_object_names = []
        for struct_type in ("singleton", "namedobject"):
            struct_field = response.get(struct_type)
            if struct_field:
                for member in struct_field["members"]:
                    if member.startswith(child_type_suffix):
                        child_object_names.append(member[len(child_type_suffix) :])
        return child_object_names

    def _get_child_object_display_names(self) -> list[str]:
        child_object_display_names = []
        for name in self._get_child_object_names():
            name_path = self.path[0:-1]
            name_path.append((self.path[-1][0], name))
            name_path.append(("_name_", ""))
            child_object_display_names.append(
                PyMenu(self.service, self.rules, name_path).get_state()
            )
        return child_object_display_names

    def get_object_names(self) -> Any:
        """Displays the name of objects within a container."""
        return self.service.get_object_names(self.rules, self.path)

    getChildObjectDisplayNames = get_object_names

    def __len__(self) -> int:
        """Return a count of child objects.

        Returns
        -------
        int
            Count of child objects.
        """
        return len(self._get_child_object_display_names())

    def __iter__(self) -> Iterator[PyMenu]:
        """Return the next child object.

        Yields
        -------
        Iterator[PyMenu]
            Iterator of child objects.
        """
        for name in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], name))
            yield getattr(self.__class__, f"_{self.__class__.__name__}")(
                self.service, self.rules, child_path
            )

    def _get_item(self, key: str) -> PyMenu:
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            return getattr(self.__class__, f"_{self.__class__.__name__}")(
                self.service, self.rules, child_path
            )
        else:
            raise LookupError(
                f"{key} is not found at path " f"{convert_path_to_se_path(self.path)}"
            )

    def _del_item(self, key: str) -> None:
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            self.service.delete_object(self.rules, convert_path_to_se_path(child_path))
        else:
            raise LookupError(
                f"{key} is not found at path " f"{convert_path_to_se_path(self.path)}"
            )

    def __getitem__(self, key: str) -> PyMenu:
        """Return the child object by key.

        Parameters
        ----------
        key : str
            Name of the child object.

        Returns
        -------
        PyMenu
            Child object.
        """
        return self._get_item(key)

    def __setitem__(self, key: str, value: Any) -> None:
        """Set state of the child object by name.

        Parameters
        ----------
        key : str
            Name of the child object.
        value : Any
            State of the child object.
        """
        if isinstance(value, dict) and not value:
            value["_name_"] = key
        parent_state = {f"{self.__class__.__name__}:{key}": value}
        PyMenu(self.service, self.rules, self.path[:-1]).set_state(parent_state)

    def __delitem__(self, key: str) -> None:
        """Delete the child object by name.

        Parameters
        ----------
        key : str
            Name of the child object.
        """
        self._del_item(key)

    @staticmethod
    def _get_type_and_name(type_and_name):
        return type_and_name.split(":", maxsplit=1)

    def _compare_type(self, obj_type):
        child_obj_type = self.path[-1][0]
        return child_obj_type == obj_type

    def get_state(self):
        """Returns state of the container."""
        parent_state = PyMenu(self.service, self.rules, self.path[:-1]).get_state()
        returned_state = {}

        for key, value in parent_state.items():
            type_and_name = self._get_type_and_name(key)
            if len(type_and_name) == 2 and self._compare_type(type_and_name[0]):
                returned_state[type_and_name[1]] = value

        return dict(sorted(returned_state.items()))


class PyQuery:
    """Query class using the StateEngine-based DatamodelService as the backend. Use this
    class instead of directly calling the DatamodelService's method.

    Methods
    -------
    __call__()
        Execute the query.
    help()
        Print the query help string.
    """

    docstring = None
    _stored_static_info = {}

    def __init__(
        self, service: DatamodelService, rules: str, query: str, path: Path = None
    ):
        """__init__ method of PyQuery class."""
        self.service = service
        self.rules = rules
        self.query = query
        if path is None:
            self.path = []
        else:
            self.path = path

    def __call__(self, *args, **kwds) -> Any:
        """Execute the query.

        Returns
        -------
        Any
            Return value.
        """
        return self.service.execute_query(
            self.rules, convert_path_to_se_path(self.path), self.query, kwds
        )

    def help(self) -> None:
        """Prints help string."""
        response = self.service.get_specs(
            self.rules, convert_path_to_se_path(self.path)
        )
        help_string = _get_value_from_message_dict(
            response, [member_specs_oneof_fields, "query", "helpstring"]
        )
        print(help_string)


class PyCommand:
    """Command class using the StateEngine-based DatamodelService as the backend. Use
    this class instead of directly calling the DatamodelService's method.

    Methods
    -------
    __call__()
        Execute the command.
    help()
        Print the command help string.
    """

    _stored_static_info: dict[str, dict[str, Any]] = {}

    def __init__(
        self,
        service: DatamodelService,
        rules: str,
        command: str,
        path: Optional[Path] = None,
    ) -> None:
        """__init__ method of PyCommand class."""
        self.service = service
        self.rules = rules
        self.command = command
        if path is None:
            self.path = []
        else:
            self.path = path

    def __call__(self, *args, **kwds) -> Any:
        """Execute the command.

        Returns
        -------
        Any
            Return value.
        """
        return self.service.execute_command(
            self.rules, convert_path_to_se_path(self.path), self.command, kwds
        )

    def help(self) -> None:
        """Prints help string."""
        response = self.service.get_specs(
            self.rules, convert_path_to_se_path(self.path)
        )
        help_string = _get_value_from_message_dict(
            response, [member_specs_oneof_fields, "common", "helpstring"]
        )
        print(help_string)

    def _create_command_arguments(self) -> str:
        commandid = self.service.create_command_arguments(
            self.rules, convert_path_to_se_path(self.path), self.command
        )
        return commandid

    def _get_static_info(self) -> dict[str, Any]:
        if self.rules not in PyCommand._stored_static_info.keys():
            # Populate the static info with respect to a rules only if the
            # same info has not been obtained in another context already.
            # If the information is available, we can use it without additional remote calls.
            response = self.service.get_static_info(self.rules)
            PyCommand._stored_static_info[self.rules] = response
        return PyCommand._stored_static_info[self.rules]

    def create_instance(self) -> Optional["PyCommandArguments"]:
        """Create a command instance."""
        try:
            static_info = self._get_static_info()
            id = self._create_command_arguments()
            return PyCommandArguments(
                self.service,
                self.rules,
                self.command,
                self.path.copy(),
                id,
                static_info,
            )
        except RuntimeError:
            logger.warning(
                "Create command arguments object is available from 23.1 onwards"
            )


class PyCommandArgumentsSubItem(PyCallableStateObject):
    """Class representing command argument in datamodel."""

    def __init__(
        self,
        parent,
        name: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        parent_arg,
    ) -> None:
        """__init__ method of PyCommandArgumentsSubItem class."""
        self.parent = parent
        self.name = name

        self.service = service
        self.rules = rules
        self.path = path
        self.parent_arg = parent_arg

    def get_state(self) -> Any:
        """Get state of the command argument."""
        parent_state = self.parent.get_state()
        return parent_state[self.name]

    getState = get_state

    def set_state(self, state) -> Any:
        """Set state of the command argument."""
        parent_state = self.parent.get_state()
        parent_state[self.name] = state
        self.parent.set_state(parent_state)

    setState = set_state

    def get_attr(self, attrib: str) -> Any:
        """Get attribute value of the command argument.

        Parameters
        ----------
        attrib : str
            attribute name

        Returns
        -------
        Any
            attribute value
        """
        attrib_path = f"{self.name}/{attrib}"
        return self.parent.get_attr(attrib_path)

    getAttribValue = get_attr

    def help(self) -> None:
        pass


class PyCommandArguments(PyStateContainer):
    """Class representing command arguments in datamodel."""

    def __init__(
        self,
        service: DatamodelService,
        rules: str,
        command: str,
        path: Path,
        id: str,
        static_info,
    ) -> None:
        """__init__ method of PyCommandArguments class."""
        self.static_info = static_info
        super().__init__(service, rules, path)
        self.path.append((command, id))
        self.command = command
        self.id = id

    def __del__(self) -> None:
        try:
            self.service.delete_command_arguments(
                self.rules,
                convert_path_to_se_path(self.path[:-1]),
                self.path[-1][0],
                self.path[-1][1],
            )
        except Exception as exc:
            logger.info("__del__ %s: %s" % (type(exc).__name__, exc))

    def __getattr__(self, attr: str) -> Optional[PyCommandArgumentsSubItem]:
        for arg in _get_value_from_message_dict(
            self.static_info, ["commands", self.command, "commandinfo", "args"]
        ):
            if arg["name"] == attr:
                mode = DataModelType.get_mode(arg["type"])
                py_class = mode.value[1]
                return py_class(self, attr, self.service, self.rules, self.path, arg)

    def get_attr(self, attrib: str) -> Any:
        """Get attribute value of the current object.

        Parameters
        ----------
        attrib : str
            Name of the attribute.

        Returns
        -------
        Any
            Value of the attribute.
        """
        return self._get_remote_attr(attrib)


class PyTextualCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyTextual):
    """Class representing textual command argument in datamodel."""

    def __init__(
        self,
        parent,
        attr: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ) -> None:
        """__init__ method of PyTextualCommandArgumentsSubItem class."""
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyTextual.__init__(self, service, rules, path)


class PyNumericalCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyNumerical):
    """Class representing numerical command argument in datamodel."""

    def __init__(
        self,
        parent,
        attr: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ) -> None:
        """__init__ method of PyNumericalCommandArgumentsSubItem class."""
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyNumerical.__init__(self, service, rules, path)


class PyDictionaryCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyDictionary):
    """Class representing dictionary-like command argument in datamodel."""

    def __init__(
        self,
        parent,
        attr: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ) -> None:
        """__init__ method of PyDictionaryCommandArgumentsSubItem class."""
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyDictionary.__init__(self, service, rules, path)


class PyParameterCommandArgumentsSubItem(PyCommandArgumentsSubItem, PyParameter):
    """Class representing generic parameter-like command argument in datamodel."""

    def __init__(
        self,
        parent,
        attr: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ) -> None:
        """__init__ method of PyParameterCommandArgumentsSubItem class."""
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )
        PyParameter.__init__(self, service, rules, path)


class PySingletonCommandArgumentsSubItem(PyCommandArgumentsSubItem):
    """Class representing singleton-like command argument in datamodel."""

    def __init__(
        self,
        parent,
        attr: str,
        service: DatamodelService,
        rules: str,
        path: Path,
        arg,
    ) -> None:
        """__init__ method of PySingletonCommandArgumentsSubItem class."""
        PyCommandArgumentsSubItem.__init__(
            self, parent, attr, service, rules, path, arg
        )

    def __getattr__(self, attr: str) -> PyCommandArgumentsSubItem:
        arg = self.parent_arg["info"]["parameters"][attr]

        mode = DataModelType.get_mode(arg["type"])
        py_class = mode.value[1]
        return py_class(self, attr, self.service, self.rules, self.path, arg)


class DataModelType(Enum):
    """An enumeration over datamodel types."""

    # Really???

    # Tuple:   Name, Solver object type, Meshing flag, Launcher options
    # Really???
    TEXT = (["String", "ListString", "String List"], PyTextualCommandArgumentsSubItem)
    NUMBER = (
        ["Real", "Int", "ListReal", "Real List", "Integer"],
        PyNumericalCommandArgumentsSubItem,
    )
    DICTIONARY = (["Dict"], PyDictionaryCommandArgumentsSubItem)
    PARAMETER = (
        ["Bool", "Logical", "Logical List"],
        PyParameterCommandArgumentsSubItem,
    )
    MODELOBJECT = (["ModelObject"], PySingletonCommandArgumentsSubItem)

    @staticmethod
    def get_mode(mode: str) -> "DataModelType":
        """Returns the datamodel type.

        Parameters
        ----------
        mode : str
            mode

        Returns
        -------
        DataModelType
            datamodel type

        Raises
        ------
        InvalidArgument
            If an unknown mode is passed.
        """
        for m in DataModelType:
            if mode in m.value[0]:
                return m
        raise InvalidArgument(f"The specified mode: {mode} was not found.")


class PyMenuGeneric(PyMenu):
    """Generic PyMenu class for when generated API code is not available."""

    attrs = ("service", "rules", "path", "cached_attrs")

    def _get_child_names(self) -> tuple[list, list, list, list]:
        response = self.service.get_specs(
            self.rules, convert_path_to_se_path(self.path)
        )
        singleton_names = []
        creatable_type_names = []
        command_names = []
        query_names = []
        for struct_type in ("singleton", "namedobject"):
            struct_field = response.get(struct_type)
            if struct_field:
                for member in struct_field["members"]:
                    if ":" not in member:
                        singleton_names.append(member)
                creatable_type_names = struct_field.get("creatabletypes", [])
                command_names = [x["name"] for x in struct_field.get("commands", [])]
                query_names = [x["name"] for x in struct_field.get("queries", [])]
        return singleton_names, creatable_type_names, command_names, query_names

    def _get_child(
        self, name: str
    ) -> Union["PyMenuGeneric", PyNamedObjectContainer, PyCommand, PyQuery]:
        singletons, creatable_types, commands, queries = self._get_child_names()
        if name in singletons:
            child_path = self.path + [(name, "")]
            return PyMenuGeneric(self.service, self.rules, child_path)
        elif name in creatable_types:
            child_path = self.path + [(name, "")]
            return PyNamedObjectContainerGeneric(self.service, self.rules, child_path)
        elif name in commands:
            return PyCommand(self.service, self.rules, name, self.path)
        elif name in queries:
            return PyQuery(self.service, self.rules, name, self.path)
        else:
            raise LookupError(
                f"{name} is not found at path " f"{convert_path_to_se_path(self.path)}"
            )

    def __dir__(self) -> list[str]:
        return list(itertools.chain(*self._get_child_names()))

    def __getattr__(self, name: str):
        if name in PyMenuGeneric.attrs:
            return super().__getattr__(name)
        else:
            return self._get_child(name)


class PySimpleMenuGeneric(PyMenu, PyDictionary):
    """A simple implementation of PyMenuGeneric applicable only for SINGLETONS.

    This is required for the stand-alone datamodel server to avoid the usage of
    'service.get_specs'
    """

    attrs = ("service", "rules", "path")

    def _get_child(self, name: str) -> "PySimpleMenuGeneric":
        child_path = self.path + [(name, "")]
        return PySimpleMenuGeneric(self.service, self.rules, child_path)

    def __getattr__(self, name: str):
        if name in PySimpleMenuGeneric.attrs:
            return super().__getattr__(name)
        else:
            return self._get_child(name)


class PyNamedObjectContainerGeneric(PyNamedObjectContainer):
    """Generic PyNamedObjectContainer class for when generated API code is not
    available."""

    def __iter__(self) -> Iterator[PyMenuGeneric]:
        for name in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], name))
            yield PyMenuGeneric(self.service, self.rules, child_path)

    def _get_item(self, key: str) -> PyMenuGeneric:
        if key in self._get_child_object_display_names():
            child_path = self.path[:-1]
            child_path.append((self.path[-1][0], key))
            return PyMenuGeneric(self.service, self.rules, child_path)
        else:
            raise LookupError(
                f"{key} is not found at path " f"{convert_path_to_se_path(self.path)}"
            )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class model_tip_loss(Integer):
    """
    Select Tip Loss Model:
    
     - Enter 1 if using Quadratic model 
     - Enter 2 if using modified Prandtl model 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "model-tip-loss"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class solar_load:
    fluent_name = ...
    child_names = ...
    solar_model = ...
    sun_direction_vector = ...
    illumination_parameters = ...
    quad_tree_parameters = ...
    ground_reflectivity = ...
    scattering_fraction = ...
    solar_on_adjacent_fluid = ...
    direction_from_solar_calculator = ...
    solar_load_frequency = ...
    solar_calculator = ...
    apply_full_solar_irradiation = ...
    autoread_solar_data = ...
    autosave_solar_data = ...
    command_names = ...

    def solar_on_demand(self, ):
        """
        Enable  solar load on demand.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .les_spec import les_spec as les_spec_cls
from .fluctuating_velocity_algorithm import fluctuating_velocity_algorithm as fluctuating_velocity_algorithm_cls
from .number_of_fourier_modes import number_of_fourier_modes as number_of_fourier_modes_cls
from .number_of_vortices import number_of_vortices as number_of_vortices_cls
from .include_streamwise_fluctuations import include_streamwise_fluctuations as include_streamwise_fluctuations_cls
from .satisfy_mass_conservation import satisfy_mass_conservation as satisfy_mass_conservation_cls
from .scale_search_limiter import scale_search_limiter as scale_search_limiter_cls
from .turbulent_intensity_perc import turbulent_intensity_perc as turbulent_intensity_perc_cls
from .turbulent_viscosity_ratio_stg import turbulent_viscosity_ratio_stg as turbulent_viscosity_ratio_stg_cls
from .wall_distance import wall_distance as wall_distance_cls
from .volumetric_forcing import volumetric_forcing as volumetric_forcing_cls
from .forcing_zone_thickness import forcing_zone_thickness as forcing_zone_thickness_cls
from .volumetric_thickness import volumetric_thickness as volumetric_thickness_cls
from .turbulent_specification import turbulent_specification as turbulent_specification_cls
from .modified_turbulent_viscosity_1 import modified_turbulent_viscosity as modified_turbulent_viscosity_cls
from .laminar_kinetic_energy_1 import laminar_kinetic_energy as laminar_kinetic_energy_cls
from .intermittency_1 import intermittency as intermittency_cls
from .turbulent_kinetic_energy_1 import turbulent_kinetic_energy as turbulent_kinetic_energy_cls
from .turbulent_dissipation_rate_1 import turbulent_dissipation_rate as turbulent_dissipation_rate_cls
from .specific_dissipation_rate_1 import specific_dissipation_rate as specific_dissipation_rate_cls
from .velocity_variance_scale_1 import velocity_variance_scale as velocity_variance_scale_cls
from .turbulent_intensity_1 import turbulent_intensity as turbulent_intensity_cls
from .turbulent_length_scale_1 import turbulent_length_scale as turbulent_length_scale_cls
from .hydraulic_diameter_1 import hydraulic_diameter as hydraulic_diameter_cls
from .turbulent_viscosity_ratio_real_1 import turbulent_viscosity_ratio_real as turbulent_viscosity_ratio_real_cls
from .turbulent_viscosity_ratio_1 import turbulent_viscosity_ratio as turbulent_viscosity_ratio_cls
from .reynolds_stress_specification import reynolds_stress_specification as reynolds_stress_specification_cls
from .uu_reynolds_stresses_1 import uu_reynolds_stresses as uu_reynolds_stresses_cls
from .vv_reynolds_stresses_1 import vv_reynolds_stresses as vv_reynolds_stresses_cls
from .ww_reynolds_stresses_1 import ww_reynolds_stresses as ww_reynolds_stresses_cls
from .uv_reynolds_stresses_1 import uv_reynolds_stresses as uv_reynolds_stresses_cls
from .vw_reynolds_stresses_1 import vw_reynolds_stresses as vw_reynolds_stresses_cls
from .uw_reynolds_stresses_1 import uw_reynolds_stresses as uw_reynolds_stresses_cls
from .subgrid_kinetic_energy_specification import subgrid_kinetic_energy_specification as subgrid_kinetic_energy_specification_cls
from .subgrid_kinetic_energy import subgrid_kinetic_energy as subgrid_kinetic_energy_cls
from .subgrid_turbulent_intensity import subgrid_turbulent_intensity as subgrid_turbulent_intensity_cls
class turbulence(Group):
    """
    Help not available.
    """

    fluent_name = "turbulence"

    child_names = \
        ['les_spec', 'fluctuating_velocity_algorithm',
         'number_of_fourier_modes', 'number_of_vortices',
         'include_streamwise_fluctuations', 'satisfy_mass_conservation',
         'scale_search_limiter', 'turbulent_intensity_perc',
         'turbulent_viscosity_ratio_stg', 'wall_distance',
         'volumetric_forcing', 'forcing_zone_thickness',
         'volumetric_thickness', 'turbulent_specification',
         'modified_turbulent_viscosity', 'laminar_kinetic_energy',
         'intermittency', 'turbulent_kinetic_energy',
         'turbulent_dissipation_rate', 'specific_dissipation_rate',
         'velocity_variance_scale', 'turbulent_intensity',
         'turbulent_length_scale', 'hydraulic_diameter',
         'turbulent_viscosity_ratio_real', 'turbulent_viscosity_ratio',
         'reynolds_stress_specification', 'uu_reynolds_stresses',
         'vv_reynolds_stresses', 'ww_reynolds_stresses',
         'uv_reynolds_stresses', 'vw_reynolds_stresses',
         'uw_reynolds_stresses', 'subgrid_kinetic_energy_specification',
         'subgrid_kinetic_energy', 'subgrid_turbulent_intensity']

    les_spec: les_spec_cls = les_spec_cls
    """
    les_spec child of turbulence.
    """
    fluctuating_velocity_algorithm: fluctuating_velocity_algorithm_cls = fluctuating_velocity_algorithm_cls
    """
    fluctuating_velocity_algorithm child of turbulence.
    """
    number_of_fourier_modes: number_of_fourier_modes_cls = number_of_fourier_modes_cls
    """
    number_of_fourier_modes child of turbulence.
    """
    number_of_vortices: number_of_vortices_cls = number_of_vortices_cls
    """
    number_of_vortices child of turbulence.
    """
    include_streamwise_fluctuations: include_streamwise_fluctuations_cls = include_streamwise_fluctuations_cls
    """
    include_streamwise_fluctuations child of turbulence.
    """
    satisfy_mass_conservation: satisfy_mass_conservation_cls = satisfy_mass_conservation_cls
    """
    satisfy_mass_conservation child of turbulence.
    """
    scale_search_limiter: scale_search_limiter_cls = scale_search_limiter_cls
    """
    scale_search_limiter child of turbulence.
    """
    turbulent_intensity_perc: turbulent_intensity_perc_cls = turbulent_intensity_perc_cls
    """
    turbulent_intensity_perc child of turbulence.
    """
    turbulent_viscosity_ratio_stg: turbulent_viscosity_ratio_stg_cls = turbulent_viscosity_ratio_stg_cls
    """
    turbulent_viscosity_ratio_stg child of turbulence.
    """
    wall_distance: wall_distance_cls = wall_distance_cls
    """
    wall_distance child of turbulence.
    """
    volumetric_forcing: volumetric_forcing_cls = volumetric_forcing_cls
    """
    volumetric_forcing child of turbulence.
    """
    forcing_zone_thickness: forcing_zone_thickness_cls = forcing_zone_thickness_cls
    """
    forcing_zone_thickness child of turbulence.
    """
    volumetric_thickness: volumetric_thickness_cls = volumetric_thickness_cls
    """
    volumetric_thickness child of turbulence.
    """
    turbulent_specification: turbulent_specification_cls = turbulent_specification_cls
    """
    turbulent_specification child of turbulence.
    """
    modified_turbulent_viscosity: modified_turbulent_viscosity_cls = modified_turbulent_viscosity_cls
    """
    modified_turbulent_viscosity child of turbulence.
    """
    laminar_kinetic_energy: laminar_kinetic_energy_cls = laminar_kinetic_energy_cls
    """
    laminar_kinetic_energy child of turbulence.
    """
    intermittency: intermittency_cls = intermittency_cls
    """
    intermittency child of turbulence.
    """
    turbulent_kinetic_energy: turbulent_kinetic_energy_cls = turbulent_kinetic_energy_cls
    """
    turbulent_kinetic_energy child of turbulence.
    """
    turbulent_dissipation_rate: turbulent_dissipation_rate_cls = turbulent_dissipation_rate_cls
    """
    turbulent_dissipation_rate child of turbulence.
    """
    specific_dissipation_rate: specific_dissipation_rate_cls = specific_dissipation_rate_cls
    """
    specific_dissipation_rate child of turbulence.
    """
    velocity_variance_scale: velocity_variance_scale_cls = velocity_variance_scale_cls
    """
    velocity_variance_scale child of turbulence.
    """
    turbulent_intensity: turbulent_intensity_cls = turbulent_intensity_cls
    """
    turbulent_intensity child of turbulence.
    """
    turbulent_length_scale: turbulent_length_scale_cls = turbulent_length_scale_cls
    """
    turbulent_length_scale child of turbulence.
    """
    hydraulic_diameter: hydraulic_diameter_cls = hydraulic_diameter_cls
    """
    hydraulic_diameter child of turbulence.
    """
    turbulent_viscosity_ratio_real: turbulent_viscosity_ratio_real_cls = turbulent_viscosity_ratio_real_cls
    """
    turbulent_viscosity_ratio_real child of turbulence.
    """
    turbulent_viscosity_ratio: turbulent_viscosity_ratio_cls = turbulent_viscosity_ratio_cls
    """
    turbulent_viscosity_ratio child of turbulence.
    """
    reynolds_stress_specification: reynolds_stress_specification_cls = reynolds_stress_specification_cls
    """
    reynolds_stress_specification child of turbulence.
    """
    uu_reynolds_stresses: uu_reynolds_stresses_cls = uu_reynolds_stresses_cls
    """
    uu_reynolds_stresses child of turbulence.
    """
    vv_reynolds_stresses: vv_reynolds_stresses_cls = vv_reynolds_stresses_cls
    """
    vv_reynolds_stresses child of turbulence.
    """
    ww_reynolds_stresses: ww_reynolds_stresses_cls = ww_reynolds_stresses_cls
    """
    ww_reynolds_stresses child of turbulence.
    """
    uv_reynolds_stresses: uv_reynolds_stresses_cls = uv_reynolds_stresses_cls
    """
    uv_reynolds_stresses child of turbulence.
    """
    vw_reynolds_stresses: vw_reynolds_stresses_cls = vw_reynolds_stresses_cls
    """
    vw_reynolds_stresses child of turbulence.
    """
    uw_reynolds_stresses: uw_reynolds_stresses_cls = uw_reynolds_stresses_cls
    """
    uw_reynolds_stresses child of turbulence.
    """
    subgrid_kinetic_energy_specification: subgrid_kinetic_energy_specification_cls = subgrid_kinetic_energy_specification_cls
    """
    subgrid_kinetic_energy_specification child of turbulence.
    """
    subgrid_kinetic_energy: subgrid_kinetic_energy_cls = subgrid_kinetic_energy_cls
    """
    subgrid_kinetic_energy child of turbulence.
    """
    subgrid_turbulent_intensity: subgrid_turbulent_intensity_cls = subgrid_turbulent_intensity_cls
    """
    subgrid_turbulent_intensity child of turbulence.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_12 import enabled as enabled_cls
from .solution_method_1 import solution_method as solution_method_cls
from .echem_model import echem_model as echem_model_cls
from .zone_assignment_1 import zone_assignment as zone_assignment_cls
from .contact_resistance import contact_resistance as contact_resistance_cls
from .ntgk_model_settings import ntgk_model_settings as ntgk_model_settings_cls
from .ecm_model_settings import ecm_model_settings as ecm_model_settings_cls
from .p2d_model_settings import p2d_model_settings as p2d_model_settings_cls
from .eload_condition import eload_condition as eload_condition_cls
from .echem_stop_criterion import echem_stop_criterion as echem_stop_criterion_cls
from .cell_clustering import cell_clustering as cell_clustering_cls
from .solution_option import solution_option as solution_option_cls
from .life_model import life_model as life_model_cls
from .swelling_model import swelling_model as swelling_model_cls
from .thermal_abuse_model import thermal_abuse_model as thermal_abuse_model_cls
from .pack_builder import pack_builder as pack_builder_cls
from .rom_tool_kit import rom_tool_kit as rom_tool_kit_cls
from .orthotropic_k import orthotropic_k as orthotropic_k_cls
from .udf_hooks import udf_hooks as udf_hooks_cls
from .parameter_estimation_tool import parameter_estimation_tool as parameter_estimation_tool_cls
from .standalone_echem_model import standalone_echem_model as standalone_echem_model_cls
class battery(Group):
    """
    'battery' child.
    """

    fluent_name = "battery"

    child_names = \
        ['enabled', 'solution_method', 'echem_model', 'zone_assignment',
         'contact_resistance', 'ntgk_model_settings', 'ecm_model_settings',
         'p2d_model_settings', 'eload_condition', 'echem_stop_criterion',
         'cell_clustering', 'solution_option', 'life_model', 'swelling_model',
         'thermal_abuse_model', 'pack_builder', 'rom_tool_kit',
         'orthotropic_k', 'udf_hooks']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of battery.
    """
    solution_method: solution_method_cls = solution_method_cls
    """
    solution_method child of battery.
    """
    echem_model: echem_model_cls = echem_model_cls
    """
    echem_model child of battery.
    """
    zone_assignment: zone_assignment_cls = zone_assignment_cls
    """
    zone_assignment child of battery.
    """
    contact_resistance: contact_resistance_cls = contact_resistance_cls
    """
    contact_resistance child of battery.
    """
    ntgk_model_settings: ntgk_model_settings_cls = ntgk_model_settings_cls
    """
    ntgk_model_settings child of battery.
    """
    ecm_model_settings: ecm_model_settings_cls = ecm_model_settings_cls
    """
    ecm_model_settings child of battery.
    """
    p2d_model_settings: p2d_model_settings_cls = p2d_model_settings_cls
    """
    p2d_model_settings child of battery.
    """
    eload_condition: eload_condition_cls = eload_condition_cls
    """
    eload_condition child of battery.
    """
    echem_stop_criterion: echem_stop_criterion_cls = echem_stop_criterion_cls
    """
    echem_stop_criterion child of battery.
    """
    cell_clustering: cell_clustering_cls = cell_clustering_cls
    """
    cell_clustering child of battery.
    """
    solution_option: solution_option_cls = solution_option_cls
    """
    solution_option child of battery.
    """
    life_model: life_model_cls = life_model_cls
    """
    life_model child of battery.
    """
    swelling_model: swelling_model_cls = swelling_model_cls
    """
    swelling_model child of battery.
    """
    thermal_abuse_model: thermal_abuse_model_cls = thermal_abuse_model_cls
    """
    thermal_abuse_model child of battery.
    """
    pack_builder: pack_builder_cls = pack_builder_cls
    """
    pack_builder child of battery.
    """
    rom_tool_kit: rom_tool_kit_cls = rom_tool_kit_cls
    """
    rom_tool_kit child of battery.
    """
    orthotropic_k: orthotropic_k_cls = orthotropic_k_cls
    """
    orthotropic_k child of battery.
    """
    udf_hooks: udf_hooks_cls = udf_hooks_cls
    """
    udf_hooks child of battery.
    """
    command_names = \
        ['parameter_estimation_tool', 'standalone_echem_model']

    parameter_estimation_tool: parameter_estimation_tool_cls = parameter_estimation_tool_cls
    """
    parameter_estimation_tool command of battery.
    """
    standalone_echem_model: standalone_echem_model_cls = standalone_echem_model_cls
    """
    standalone_echem_model command of battery.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class number_of_eulerian_discrete_phases(IntegerList):
    """
    Sets the number of phases, calculated with the Discrete Phase model.
    The sum of Eulerian and Discrete phases has to be in the range (2,20).
    """

    fluent_name = "number-of-eulerian-discrete-phases"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thread_id import thread_id as thread_id_cls
from .growth_rate import growth_rate as growth_rate_cls
class redistribute_boundary_layer(Command):
    """
    Enforce growth rate in boundary layer.
    
    Parameters
    ----------
        thread_id : int
            'thread_id' child.
        growth_rate : real
            'growth_rate' child.
    
    """

    fluent_name = "redistribute-boundary-layer"

    argument_names = \
        ['thread_id', 'growth_rate']

    thread_id: thread_id_cls = thread_id_cls
    """
    thread_id argument of redistribute_boundary_layer.
    """
    growth_rate: growth_rate_cls = growth_rate_cls
    """
    growth_rate argument of redistribute_boundary_layer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class picture_options:
    fluent_name = ...
    child_names = ...
    color_mode = ...
    invert_background = ...
    driver_options = ...
    standard_resolution = ...
    jpeg_hardcopy_quality = ...
    landscape = ...
    x_resolution = ...
    y_resolution = ...
    dpi = ...
    use_window_resolution = ...
    command_names = ...

    def list_color_mode(self, ):
        """
        'list_color_mode' command.
        """

    def preview(self, ):
        """
        Display a preview image of a hardcopy.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .x import x as x_cls
from .x_2 import x_2 as x_2_cls
from .y import y as y_cls
from .y_2 import y_2 as y_2_cls
from .z import z as z_cls
from .z_2 import z_2 as z_2_cls
from .azimuthal_start_angle import azimuthal_start_angle as azimuthal_start_angle_cls
from .azimuthal_stop_angle import azimuthal_stop_angle as azimuthal_stop_angle_cls
from .injection_surfaces import injection_surfaces as injection_surfaces_cls
from .random_surface_inj import random_surface_inj as random_surface_inj_cls
class location(Group):
    """
    'location' child.
    """

    fluent_name = "location"

    child_names = \
        ['x', 'x_2', 'y', 'y_2', 'z', 'z_2', 'azimuthal_start_angle',
         'azimuthal_stop_angle', 'injection_surfaces', 'random_surface_inj']

    x: x_cls = x_cls
    """
    x child of location.
    """
    x_2: x_2_cls = x_2_cls
    """
    x_2 child of location.
    """
    y: y_cls = y_cls
    """
    y child of location.
    """
    y_2: y_2_cls = y_2_cls
    """
    y_2 child of location.
    """
    z: z_cls = z_cls
    """
    z child of location.
    """
    z_2: z_2_cls = z_2_cls
    """
    z_2 child of location.
    """
    azimuthal_start_angle: azimuthal_start_angle_cls = azimuthal_start_angle_cls
    """
    azimuthal_start_angle child of location.
    """
    azimuthal_stop_angle: azimuthal_stop_angle_cls = azimuthal_stop_angle_cls
    """
    azimuthal_stop_angle child of location.
    """
    injection_surfaces: injection_surfaces_cls = injection_surfaces_cls
    """
    injection_surfaces child of location.
    """
    random_surface_inj: random_surface_inj_cls = random_surface_inj_cls
    """
    random_surface_inj child of location.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .const_number_in_parcel import const_number_in_parcel as const_number_in_parcel_cls
from .const_parcel_mass import const_parcel_mass as const_parcel_mass_cls
from .const_parcel_diameter import const_parcel_diameter as const_parcel_diameter_cls
class parcel_method(Group):
    """
    'parcel_method' child.
    """

    fluent_name = "parcel-method"

    child_names = \
        ['option', 'const_number_in_parcel', 'const_parcel_mass',
         'const_parcel_diameter']

    option: option_cls = option_cls
    """
    option child of parcel_method.
    """
    const_number_in_parcel: const_number_in_parcel_cls = const_number_in_parcel_cls
    """
    const_number_in_parcel child of parcel_method.
    """
    const_parcel_mass: const_parcel_mass_cls = const_parcel_mass_cls
    """
    const_parcel_mass child of parcel_method.
    """
    const_parcel_diameter: const_parcel_diameter_cls = const_parcel_diameter_cls
    """
    const_parcel_diameter child of parcel_method.
    """



"""Module for Field data streaming."""

from typing import Callable, Dict, List, Union

from ansys.api.fluent.v0 import field_data_pb2 as FieldDataProtoModule
from ansys.fluent.core.services.field_data import ChunkParser
from ansys.fluent.core.streaming_services.streaming import StreamingService


class FieldDataStreaming(StreamingService):
    """Class wrapping the Field gRPC streaming service of Fluent.

    Parameters
    ----------
    session_id : str
        Session ID.
    service : FieldDataService
        FieldData streaming service.
    """

    def __init__(self, session_id: str, service):
        super().__init__(
            stream_begin_method="BeginFieldsStreaming",
            target=FieldDataStreaming._process_streaming,
            streaming_service=service,
        )
        self._session_id: str = session_id

    def _process_streaming(self, id, stream_begin_method, started_evt, *args, **kwargs):
        """Processes field data streaming."""
        request = FieldDataProtoModule.BeginFieldsStreamingRequest(*args, **kwargs)
        ChunkParser(self).extract_fields(
            self._streaming_service.begin_streaming(
                request, started_evt, id=id, stream_begin_method=stream_begin_method
            )
        )

    def callbacks(self) -> List[List[Union[Callable, List, Dict]]]:
        """Get list of callbacks along with arguments and keyword arguments."""
        return self._service_callbacks.values()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .pv_coupling_controls import pv_coupling_controls as pv_coupling_controls_cls
from .pv_coupling_method import pv_coupling_method as pv_coupling_method_cls
from .gradient_controls import gradient_controls as gradient_controls_cls
from .specify_gradient_method import specify_gradient_method as specify_gradient_method_cls
class methods(Group):
    """
    'methods' child.
    """

    fluent_name = "methods"

    child_names = \
        ['pv_coupling_controls', 'pv_coupling_method', 'gradient_controls',
         'specify_gradient_method']

    pv_coupling_controls: pv_coupling_controls_cls = pv_coupling_controls_cls
    """
    pv_coupling_controls child of methods.
    """
    pv_coupling_method: pv_coupling_method_cls = pv_coupling_method_cls
    """
    pv_coupling_method child of methods.
    """
    gradient_controls: gradient_controls_cls = gradient_controls_cls
    """
    gradient_controls child of methods.
    """
    specify_gradient_method: specify_gradient_method_cls = specify_gradient_method_cls
    """
    specify_gradient_method child of methods.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .key import key as key_cls
class add_keyframe(Command):
    """
    Add keyframe.
    
    Parameters
    ----------
        key : int
            'key' child.
    
    """

    fluent_name = "add-keyframe"

    argument_names = \
        ['key']

    key: key_cls = key_cls
    """
    key argument of add_keyframe.
    """



from ansys.fluent.core.launcher.launcher import launch_fluent
from ansys.fluent.core.session_solver import Solver


def setup_for_fluent(*args, **kwargs):
    """Returns global PyConsole objects."""
    session = launch_fluent(*args, **kwargs)
    globals = {}
    if kwargs.get("mode", "solver") == "meshing":
        globals["meshing"] = session
        globals["PartManagement"] = session.PartManagement
        globals["PMFileManagement"] = session.PMFileManagement
        globals["solver"] = Solver(fluent_connection=session.fluent_connection)
    else:
        globals["solver"] = session

    globals["preferences"] = session.preferences
    globals["workflow"] = session.workflow

    return globals



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .rough_bc import rough_bc as rough_bc_cls
from .rough_option import rough_option as rough_option_cls
from .rough_nasa import rough_nasa as rough_nasa_cls
from .rough_shin_et_al import rough_shin_et_al as rough_shin_et_al_cls
from .rough_data import rough_data as rough_data_cls
from .roughness_height import roughness_height as roughness_height_cls
from .roughness_const import roughness_const as roughness_const_cls
from .roughness_height_cp import roughness_height_cp as roughness_height_cp_cls
from .roughness_const_cp import roughness_const_cp as roughness_const_cp_cls
from .roughness_const_nasa import roughness_const_nasa as roughness_const_nasa_cls
from .roughness_const_shin import roughness_const_shin as roughness_const_shin_cls
from .roughness_const_data import roughness_const_data as roughness_const_data_cls
from .variable_roughness import variable_roughness as variable_roughness_cls
from .free_stream_velocity import free_stream_velocity as free_stream_velocity_cls
from .free_stream_temp import free_stream_temp as free_stream_temp_cls
from .characteristic_length import characteristic_length as characteristic_length_cls
from .free_stream_temp_cp import free_stream_temp_cp as free_stream_temp_cp_cls
from .characteristic_length_cp import characteristic_length_cp as characteristic_length_cp_cls
from .liquid_content import liquid_content as liquid_content_cls
from .liquid_content_cp import liquid_content_cp as liquid_content_cp_cls
from .droplet_diameter import droplet_diameter as droplet_diameter_cls
class turbulence(Group):
    """
    Help not available.
    """

    fluent_name = "turbulence"

    child_names = \
        ['rough_bc', 'rough_option', 'rough_nasa', 'rough_shin_et_al',
         'rough_data', 'roughness_height', 'roughness_const',
         'roughness_height_cp', 'roughness_const_cp', 'roughness_const_nasa',
         'roughness_const_shin', 'roughness_const_data', 'variable_roughness',
         'free_stream_velocity', 'free_stream_temp', 'characteristic_length',
         'free_stream_temp_cp', 'characteristic_length_cp', 'liquid_content',
         'liquid_content_cp', 'droplet_diameter']

    rough_bc: rough_bc_cls = rough_bc_cls
    """
    rough_bc child of turbulence.
    """
    rough_option: rough_option_cls = rough_option_cls
    """
    rough_option child of turbulence.
    """
    rough_nasa: rough_nasa_cls = rough_nasa_cls
    """
    rough_nasa child of turbulence.
    """
    rough_shin_et_al: rough_shin_et_al_cls = rough_shin_et_al_cls
    """
    rough_shin_et_al child of turbulence.
    """
    rough_data: rough_data_cls = rough_data_cls
    """
    rough_data child of turbulence.
    """
    roughness_height: roughness_height_cls = roughness_height_cls
    """
    roughness_height child of turbulence.
    """
    roughness_const: roughness_const_cls = roughness_const_cls
    """
    roughness_const child of turbulence.
    """
    roughness_height_cp: roughness_height_cp_cls = roughness_height_cp_cls
    """
    roughness_height_cp child of turbulence.
    """
    roughness_const_cp: roughness_const_cp_cls = roughness_const_cp_cls
    """
    roughness_const_cp child of turbulence.
    """
    roughness_const_nasa: roughness_const_nasa_cls = roughness_const_nasa_cls
    """
    roughness_const_nasa child of turbulence.
    """
    roughness_const_shin: roughness_const_shin_cls = roughness_const_shin_cls
    """
    roughness_const_shin child of turbulence.
    """
    roughness_const_data: roughness_const_data_cls = roughness_const_data_cls
    """
    roughness_const_data child of turbulence.
    """
    variable_roughness: variable_roughness_cls = variable_roughness_cls
    """
    variable_roughness child of turbulence.
    """
    free_stream_velocity: free_stream_velocity_cls = free_stream_velocity_cls
    """
    free_stream_velocity child of turbulence.
    """
    free_stream_temp: free_stream_temp_cls = free_stream_temp_cls
    """
    free_stream_temp child of turbulence.
    """
    characteristic_length: characteristic_length_cls = characteristic_length_cls
    """
    characteristic_length child of turbulence.
    """
    free_stream_temp_cp: free_stream_temp_cp_cls = free_stream_temp_cp_cls
    """
    free_stream_temp_cp child of turbulence.
    """
    characteristic_length_cp: characteristic_length_cp_cls = characteristic_length_cp_cls
    """
    characteristic_length_cp child of turbulence.
    """
    liquid_content: liquid_content_cls = liquid_content_cls
    """
    liquid_content child of turbulence.
    """
    liquid_content_cp: liquid_content_cp_cls = liquid_content_cp_cls
    """
    liquid_content_cp child of turbulence.
    """
    droplet_diameter: droplet_diameter_cls = droplet_diameter_cls
    """
    droplet_diameter child of turbulence.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .plane_surface import plane_surface as plane_surface_cls
class surfaces(Group):
    """
    'surfaces' child.
    """

    fluent_name = "surfaces"

    child_names = \
        ['plane_surface']

    plane_surface: plane_surface_cls = plane_surface_cls
    """
    plane_surface child of surfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .cell_distance import cell_distance as cell_distance_cls
from .normal_distance import normal_distance as normal_distance_cls
from .volume_distance import volume_distance as volume_distance_cls
class distance_option(Group):
    """
    'distance_option' child.
    """

    fluent_name = "distance-option"

    child_names = \
        ['option', 'cell_distance', 'normal_distance', 'volume_distance']

    option: option_cls = option_cls
    """
    option child of distance_option.
    """
    cell_distance: cell_distance_cls = cell_distance_cls
    """
    cell_distance child of distance_option.
    """
    normal_distance: normal_distance_cls = normal_distance_cls
    """
    normal_distance child of distance_option.
    """
    volume_distance: volume_distance_cls = volume_distance_cls
    """
    volume_distance child of distance_option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class fmg_initialization:
    fluent_name = ...
    child_names = ...
    fmg_courant_number = ...
    enable_fmg_verbose = ...
    command_names = ...

    def customize_fmg_initialization(self, multi_level_grid: int, residual_reduction_level: List[Union[float, str]], cycle_count: List[Union[float, str]]):
        """
        'customize_fmg_initialization' command.
        
        Parameters
        ----------
            multi_level_grid : int
                'multi_level_grid' child.
            residual_reduction_level : typing.List[real]
                'residual_reduction_level' child.
            cycle_count : typing.List[real]
                'cycle_count' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class geometry_names(StringList, _HasAllowedValuesMixin):
    """
    Select UTL Geometry.
    """

    fluent_name = "geometry-names"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mesh_motion import mesh_motion as mesh_motion_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity import moving_mesh_velocity as moving_mesh_velocity_cls
from .moving_mesh_axis_origin import moving_mesh_axis_origin as moving_mesh_axis_origin_cls
from .moving_mesh_axis_direction import moving_mesh_axis_direction as moving_mesh_axis_direction_cls
from .moving_mesh_zone_motion_function import moving_mesh_zone_motion_function as moving_mesh_zone_motion_function_cls
class mesh_motion(Group):
    """
    Help not available.
    """

    fluent_name = "mesh-motion"

    child_names = \
        ['mesh_motion', 'mgrid_enable_transient', 'mgrid_relative_to_thread',
         'mgrid_omega', 'moving_mesh_velocity', 'moving_mesh_axis_origin',
         'moving_mesh_axis_direction', 'moving_mesh_zone_motion_function']

    mesh_motion: mesh_motion_cls = mesh_motion_cls
    """
    mesh_motion child of mesh_motion.
    """
    mgrid_enable_transient: mgrid_enable_transient_cls = mgrid_enable_transient_cls
    """
    mgrid_enable_transient child of mesh_motion.
    """
    mgrid_relative_to_thread: mgrid_relative_to_thread_cls = mgrid_relative_to_thread_cls
    """
    mgrid_relative_to_thread child of mesh_motion.
    """
    mgrid_omega: mgrid_omega_cls = mgrid_omega_cls
    """
    mgrid_omega child of mesh_motion.
    """
    moving_mesh_velocity: moving_mesh_velocity_cls = moving_mesh_velocity_cls
    """
    moving_mesh_velocity child of mesh_motion.
    """
    moving_mesh_axis_origin: moving_mesh_axis_origin_cls = moving_mesh_axis_origin_cls
    """
    moving_mesh_axis_origin child of mesh_motion.
    """
    moving_mesh_axis_direction: moving_mesh_axis_direction_cls = moving_mesh_axis_direction_cls
    """
    moving_mesh_axis_direction child of mesh_motion.
    """
    moving_mesh_zone_motion_function: moving_mesh_zone_motion_function_cls = moving_mesh_zone_motion_function_cls
    """
    moving_mesh_zone_motion_function child of mesh_motion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_list import file_name_list as file_name_list_cls
class read_journal(Command):
    """
    Read a journal file.
    
    Parameters
    ----------
        file_name_list : typing.List[str]
            'file_name_list' child.
    
    """

    fluent_name = "read-journal"

    argument_names = \
        ['file_name_list']

    file_name_list: file_name_list_cls = file_name_list_cls
    """
    file_name_list argument of read_journal.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .active import active as active_cls
from .min_value import min_value as min_value_cls
from .max_value import max_value as max_value_cls
from .min_transparency_value import min_transparency_value as min_transparency_value_cls
from .max_transparency_value import max_transparency_value as max_transparency_value_cls
class settings_child(Group):
    """
    'child_object_type' of settings.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['active', 'min_value', 'max_value', 'min_transparency_value',
         'max_transparency_value']

    active: active_cls = active_cls
    """
    active child of settings_child.
    """
    min_value: min_value_cls = min_value_cls
    """
    min_value child of settings_child.
    """
    max_value: max_value_cls = max_value_cls
    """
    max_value child of settings_child.
    """
    min_transparency_value: min_transparency_value_cls = min_transparency_value_cls
    """
    min_transparency_value child of settings_child.
    """
    max_transparency_value: max_transparency_value_cls = max_transparency_value_cls
    """
    max_transparency_value child of settings_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .settings_2 import settings as settings_cls
from .reset_1 import reset as reset_cls
from .invert import invert as invert_cls
class transparency_options(Group):
    """
    'transparency_options' child.
    """

    fluent_name = "transparency-options"

    child_names = \
        ['settings']

    settings: settings_cls = settings_cls
    """
    settings child of transparency_options.
    """
    command_names = \
        ['reset', 'invert']

    reset: reset_cls = reset_cls
    """
    reset command of transparency_options.
    """
    invert: invert_cls = invert_cls
    """
    invert command of transparency_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class o2o_flag(Boolean):
    """
    Use the default one-to-one interface creation method?.
    """

    fluent_name = "o2o-flag"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .cursys_1 import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
class material_orientation(Group):
    """
    Help not available.
    """

    fluent_name = "material-orientation"

    child_names = \
        ['cursys', 'cursys_name']

    cursys: cursys_cls = cursys_cls
    """
    cursys child of material_orientation.
    """
    cursys_name: cursys_name_cls = cursys_name_cls
    """
    cursys_name child of material_orientation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .background_2 import background as background_cls
from .rendering import rendering as rendering_cls
from .display_live_preview import display_live_preview as display_live_preview_cls
class raytracing_options(Group):
    """
    'raytracing_options' child.
    """

    fluent_name = "raytracing-options"

    child_names = \
        ['background', 'rendering']

    background: background_cls = background_cls
    """
    background child of raytracing_options.
    """
    rendering: rendering_cls = rendering_cls
    """
    rendering child of raytracing_options.
    """
    command_names = \
        ['display_live_preview']

    display_live_preview: display_live_preview_cls = display_live_preview_cls
    """
    display_live_preview command of raytracing_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .data_sampling import data_sampling as data_sampling_cls
from .sampling_interval import sampling_interval as sampling_interval_cls
from .statistics_shear_stress import statistics_shear_stress as statistics_shear_stress_cls
from .statistics_heat_flux import statistics_heat_flux as statistics_heat_flux_cls
from .wall_statistics import wall_statistics as wall_statistics_cls
from .force_statistics import force_statistics as force_statistics_cls
from .time_statistics_dpm import time_statistics_dpm as time_statistics_dpm_cls
from .species_list import species_list as species_list_cls
from .statistics_mixture_fraction import statistics_mixture_fraction as statistics_mixture_fraction_cls
from .statistics_reaction_progress import statistics_reaction_progress as statistics_reaction_progress_cls
from .save_cff_unsteady_statistics import save_cff_unsteady_statistics as save_cff_unsteady_statistics_cls
from .udf_cf_names import udf_cf_names as udf_cf_names_cls
class data_sampling(Group):
    """
    'data_sampling' child.
    """

    fluent_name = "data-sampling"

    child_names = \
        ['data_sampling', 'sampling_interval', 'statistics_shear_stress',
         'statistics_heat_flux', 'wall_statistics', 'force_statistics',
         'time_statistics_dpm', 'species_list', 'statistics_mixture_fraction',
         'statistics_reaction_progress', 'save_cff_unsteady_statistics',
         'udf_cf_names']

    data_sampling: data_sampling_cls = data_sampling_cls
    """
    data_sampling child of data_sampling.
    """
    sampling_interval: sampling_interval_cls = sampling_interval_cls
    """
    sampling_interval child of data_sampling.
    """
    statistics_shear_stress: statistics_shear_stress_cls = statistics_shear_stress_cls
    """
    statistics_shear_stress child of data_sampling.
    """
    statistics_heat_flux: statistics_heat_flux_cls = statistics_heat_flux_cls
    """
    statistics_heat_flux child of data_sampling.
    """
    wall_statistics: wall_statistics_cls = wall_statistics_cls
    """
    wall_statistics child of data_sampling.
    """
    force_statistics: force_statistics_cls = force_statistics_cls
    """
    force_statistics child of data_sampling.
    """
    time_statistics_dpm: time_statistics_dpm_cls = time_statistics_dpm_cls
    """
    time_statistics_dpm child of data_sampling.
    """
    species_list: species_list_cls = species_list_cls
    """
    species_list child of data_sampling.
    """
    statistics_mixture_fraction: statistics_mixture_fraction_cls = statistics_mixture_fraction_cls
    """
    statistics_mixture_fraction child of data_sampling.
    """
    statistics_reaction_progress: statistics_reaction_progress_cls = statistics_reaction_progress_cls
    """
    statistics_reaction_progress child of data_sampling.
    """
    save_cff_unsteady_statistics: save_cff_unsteady_statistics_cls = save_cff_unsteady_statistics_cls
    """
    save_cff_unsteady_statistics child of data_sampling.
    """
    udf_cf_names: udf_cf_names_cls = udf_cf_names_cls
    """
    udf_cf_names child of data_sampling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class choose_auto_time_stepping(Boolean):
    """
    Enable/Disable Automatic time stepping?.
    """

    fluent_name = "choose-auto-time-stepping?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties_1 import list_properties as list_properties_cls
from .piecewise_polynomial_child_1 import piecewise_polynomial_child

class piecewise_polynomial(ListObject[piecewise_polynomial_child]):
    """
    'piecewise_polynomial' child.
    """

    fluent_name = "piecewise-polynomial"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of piecewise_polynomial.
    """
    child_object_type: piecewise_polynomial_child = piecewise_polynomial_child
    """
    child_object_type of piecewise_polynomial.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .right import right as right_cls
from .up import up as up_cls
class orbit(Command):
    """
    Adjust the camera position without modifying the target.
    
    Parameters
    ----------
        right : real
            'right' child.
        up : real
            'up' child.
    
    """

    fluent_name = "orbit"

    argument_names = \
        ['right', 'up']

    right: right_cls = right_cls
    """
    right argument of orbit.
    """
    up: up_cls = up_cls
    """
    up argument of orbit.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class data_sampling_options:
    fluent_name = ...
    child_names = ...
    data_sets = ...
    command_names = ...

    def add_datasets(self, zone_names: List[str], domain: str, quantities: List[str], min: bool, max: bool, mean: bool, rmse: bool, moving_average: bool, average_over: int):
        """
        Add datasets.
        
        Parameters
        ----------
            zone_names : typing.List[str]
                Enter zone name list.
            domain : str
                'domain' child.
            quantities : typing.List[str]
                'quantities' child.
            min : bool
                'min' child.
            max : bool
                'max' child.
            mean : bool
                'mean' child.
            rmse : bool
                'rmse' child.
            moving_average : bool
                'moving_average' child.
            average_over : int
                'average_over' child.
        
        """

    def list_datasets(self, ):
        """
        List dataset.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .o2o_flag import o2o_flag as o2o_flag_cls
from .toggle import toggle as toggle_cls
from .delete_empty import delete_empty as delete_empty_cls
class enable_one_to_one_pairing(Command):
    """
    Use the default one-to-one interface creation method?.
    
    Parameters
    ----------
        o2o_flag : bool
            Use the default one-to-one interface creation method?.
        toggle : bool
            Would you like to proceed?.
        delete_empty : bool
            Delete empty interface interior zones from non-overlapping interfaces?.
    
    """

    fluent_name = "enable-one-to-one-pairing"

    argument_names = \
        ['o2o_flag', 'toggle', 'delete_empty']

    o2o_flag: o2o_flag_cls = o2o_flag_cls
    """
    o2o_flag argument of enable_one_to_one_pairing.
    """
    toggle: toggle_cls = toggle_cls
    """
    toggle argument of enable_one_to_one_pairing.
    """
    delete_empty: delete_empty_cls = delete_empty_cls
    """
    delete_empty argument of enable_one_to_one_pairing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class parametric_studies:
    fluent_name = ...
    command_names = ...

    def delete(self, name_list: List[str]):
        """
        Delete selected objects.
        
        Parameters
        ----------
            name_list : typing.List[str]
                Select objects to be deleted.
        
        """

    def list(self, ):
        """
        List the names of the objects.
        """

    def list_properties(self, object_name: str):
        """
        List active properties of the object.
        
        Parameters
        ----------
            object_name : str
                Select object for which properties are to be listed.
        
        """

    def make_a_copy(self, from_: str, to: str):
        """
        Create a copy of the object.
        
        Parameters
        ----------
            from_ : str
                Select the object to duplicate.
            to : str
                Specify the name of the new object.
        
        """

    def initialize(self, project_filename: str):
        """
        Start Parametric Study.
        
        Parameters
        ----------
            project_filename : str
                'project_filename' child.
        
        """

    def duplicate(self, copy_design_points: bool):
        """
        Duplicate Parametric Study.
        
        Parameters
        ----------
            copy_design_points : bool
                'copy_design_points' child.
        
        """

    def set_as_current(self, study_name: str):
        """
        Set As Current Study.
        
        Parameters
        ----------
            study_name : str
                'study_name' child.
        
        """

    def use_base_data(self, ):
        """
        Use Base Data.
        """

    def export_design_table(self, filepath: str):
        """
        Export Design Point Table.
        
        Parameters
        ----------
            filepath : str
                'filepath' child.
        
        """

    def import_design_table(self, filepath: str, delete_existing: bool):
        """
        Import Design Point Table.
        
        Parameters
        ----------
            filepath : str
                'filepath' child.
            delete_existing : bool
                'delete_existing' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class casm_cutoff_multiplier(Real):
    """
    Enter CASM cut-off multiplier :.
    """

    fluent_name = "casm-cutoff-multiplier"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class aggressive_coarsening(Boolean):
    """
    Enable aggressive AMG coarsening for coupled equation systems.
    """

    fluent_name = "aggressive-coarsening?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .across_zone_boundaries import across_zone_boundaries as across_zone_boundaries_cls
class across_zones(Command):
    """
    Enable partitioning by zone or by domain.
    
    Parameters
    ----------
        across_zone_boundaries : bool
            'across_zone_boundaries' child.
    
    """

    fluent_name = "across-zones"

    argument_names = \
        ['across_zone_boundaries']

    across_zone_boundaries: across_zone_boundaries_cls = across_zone_boundaries_cls
    """
    across_zone_boundaries argument of across_zones.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .display_2 import display as display_cls
from .copy_4 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .lic_child import lic_child

class lic(NamedObject[lic_child], _CreatableNamedObjectMixin[lic_child]):
    """
    'lic' child.
    """

    fluent_name = "lic"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy', 'display',
         'copy', 'add_to_graphics', 'clear_history']

    delete: delete_cls = delete_cls
    """
    delete command of lic.
    """
    list: list_cls = list_cls
    """
    list command of lic.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of lic.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of lic.
    """
    display: display_cls = display_cls
    """
    display command of lic.
    """
    copy: copy_cls = copy_cls
    """
    copy command of lic.
    """
    add_to_graphics: add_to_graphics_cls = add_to_graphics_cls
    """
    add_to_graphics command of lic.
    """
    clear_history: clear_history_cls = clear_history_cls
    """
    clear_history command of lic.
    """
    child_object_type: lic_child = lic_child
    """
    child_object_type of lic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .multi_phase_setting import multi_phase_setting as multi_phase_setting_cls
from .single_phase_setting import single_phase_setting as single_phase_setting_cls
class hybrid_nita_settings(Group):
    """
    Select a hybrid NITA settings option for faster performance and better robustness.
    """

    fluent_name = "hybrid-nita-settings"

    child_names = \
        ['multi_phase_setting', 'single_phase_setting']

    multi_phase_setting: multi_phase_setting_cls = multi_phase_setting_cls
    """
    multi_phase_setting child of hybrid_nita_settings.
    """
    single_phase_setting: single_phase_setting_cls = single_phase_setting_cls
    """
    single_phase_setting child of hybrid_nita_settings.
    """
